CMIP6 experiment_id values
Author: Paul J. Durack
Description: Controlled vocabulary for CMIP6
Keywords: HTML, CSS, JavaScript

# WCRP-CMIP CMIP6_CVs version: 6.2.60.0

#### Experiment IDs | Institution IDs | Source IDs | Source IDs (incl licenses) | Citations by (Source ID, Institution Id, Activity ID) | Citations by (Source ID, Institution Id, Activity ID, Experiment ID) |

experiment_id | activity id | experiment | tier | sub experiment id | parent experiment id | required model components | additional allowed model components | start year | end year | min number yrs per sim | parent activity id | description
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
experiment_id | activity id | experiment | tier | sub experiment id | parent experiment id | required model components | additional allowed model components | start year | end year | min number yrs per sim | parent activity id | description
1pctCO2 | CMIP | 1 percent per year increase in CO2 | 1 | none | piControl | AOGCM | AER CHEM BGC |  |  | 150 | CMIP | DECK: 1pctCO2
1pctCO2-4xext | ISMIP6 | extension from year 140 of 1pctCO2 with 4xCO2 | 1 | none | 1pctCO2 | AOGCM | AER CHEM BGC |  |  | 210 | CMIP | branched from 1pctCO2 run at year 140 and run with CO2 fixed at 4x pre-industrial concentration
1pctCO2-bgc | C4MIP | biogeochemically-coupled version of 1 percent per year increasing CO2 experiment | 1 | none | piControl | AOGCM BGC | AER CHEM |  |  | 150 | CMIP | Biogeochemically-coupled specified concentration simulation in which CO2 increases at a rate of 1% per year until quadrupling
1pctCO2-cdr | CDRMIP | 1 percent per year decrease in CO2 from 4xCO2 | 1 | none | 1pctCO2 | AOGCM BGC | AER CHEM |  |  | 200 | CMIP | 1 percent per year decrease in CO2 (immediately after reaching 4xCO2 in the 1pctCO2 simulation); then held constant at pre-industrial level (part of the CDR-reversibility experiment)
1pctCO2-rad | C4MIP | radiatively-coupled version of 1 percent per year increasing CO2 experiment | 2 | none | piControl | AOGCM BGC | AER CHEM |  |  | 150 | CMIP | Radiatively-coupled specified concentration simulation in which CO2 increases at a rate of 1% per year until quadrupling
1pctCO2Ndep | C4MIP | 1 percent per year increasing CO2 experiment with increasing N-deposition | 2 | none | piControl | AOGCM BGC | AER CHEM |  |  | 150 | CMIP | Fully-coupled specified concentration simulation in which CO2 increases at a rate of 1% per year until quadrupling, plus an additional scenario of anthropogenic nitrogen deposition
1pctCO2Ndep-bgc | C4MIP | biogeochemically-coupled version of 1 percent per year increasing CO2 experiment with increasing N-deposition | 2 | none | piControl | AOGCM BGC | AER CHEM |  |  | 150 | CMIP | Biogeochemically-coupled specified concentration simulation in which CO2 increases at a rate of 1% per year until quadrupling, plus an additional scenario of anthropogenic nitrogen deposition
1pctCO2to4x-withism | ISMIP6 | simulation with interactive ice sheet forced by 1 percent per year increase in CO2 to 4xCO2 (subsequently held fixed) | 1 | none | piControl-withism | AOGCM ISM | AER CHEM BGC |  |  | 350 | ISMIP6 | Idealized 1%/yr CO2 increase to 4xC02 over 140yrs and kept constant at 4xCO2 for an additional 200 to 400 yrs simulation that includes interactive ice sheets
G1 | GeoMIP | abrupt quadrupling of CO2 plus reduction in total solar irradiance | 1 | none | piControl | AOGCM | AER CHEM BGC |  |  | 100 | CMIP | Beginning from a preindustrial control run, simultaneously quadruple the CO2 concentration and reduce the solar constant such that the TOA radiative flux remains within +/m0.1 W/m2
G6SST1 | GeoMIP | SSTs, forcings, and other prescribed conditions from year 2020 of SSP5-8.5 | 2 | none | ssp585 | AGCM | AER CHEM |  |  | 10 | ScenarioMIP | Time slice at 2020 (ScenarioMIP Tier 1 high forcing scenario)
G6SST2-solar | GeoMIP | SSTs from year 2020 of SSP5-8.5; forcings and other prescribed conditions from year 2100 of G6solar | 2 | none | G6solar | AGCM | AER CHEM |  |  | 10 | GeoMIP | Time slice at 2100 (G6solar)
G6SST2-sulfur | GeoMIP | SSTs from year 2020 of SSP5-8.5; forcings and other prescribed conditions from year 2100 of G6sulfur | 2 | none | G6sulfur | AGCM | AER CHEM |  |  | 10 | GeoMIP | Time slice at 2100 (G6sulfur)
G6solar | GeoMIP | total solar irradiance reduction to reduce net forcing from SSP585 to SSP245 | 1 | none | ssp585 | AOGCM | AER CHEM BGC | 2020 | 2100 | 81 | ScenarioMIP | Using solar irradiance reduction, return the radiative forcing from a background of the ScenarioMIP high forcing to the ScenarioMIP middle forcing
G6sulfur | GeoMIP | stratospheric sulfate aerosol injection to reduce net forcing from SSP585 to SSP245 | 1 | none | ssp585 | AOGCM | AER CHEM BGC | 2020 | 2100 | 81 | ScenarioMIP | Using equatorial SO2 injection, return the radiative forcing from a background of the ScenarioMIP high forcing to the ScenarioMIP middle forcing
G7SST1-cirrus | GeoMIP | SSTs from year 2020 of SSP5-8.5; forcings and other prescribed conditions from year 2020 of SSP5-8.5 and cirrus thinning | 2 | none | ssp585 | AGCM | AER CHEM |  |  | 10 | ScenarioMIP | Time slice at 2020 (ScenarioMIP Tier 1 high forcing scenario and cirrus thinning according to G7cirrus)
G7SST2-cirrus | GeoMIP | SSTs from year 2100 of SSP5-8.5; forcings and other prescribed conditions from year 2100 of G7cirrus | 2 | none | G7cirrus | AGCM | AER CHEM |  |  | 10 | GeoMIP | Time slice at 2100 (ScenarioMIP Tier 1 high forcing scenario and cirrus thinning according to G7cirrus)
G7cirrus | GeoMIP | increase cirrus ice crystal fall speed to reduce net forcing in SSP585 by 1 W m-2 | 2 | none | ssp585 | AOGCM | AER CHEM BGC | 2020 | 2100 | 81 | ScenarioMIP | Against a background of the ScenarioMIP high forcing, reduce cirrus cloud optical depth by a constant amount
a4SST | CFMIP | as piSST but with SSTs from abrupt-4xCO2 | 2 | none | no parent | AGCM | AER CHEM |  |  | 30 | no parent | As piSST, but with monthly-varying SSTs taken from years 111-140 of each model's own abrupt-4xCO2 experiment instead of from piControl. Sea-ice is unchanged from piSST
a4SSTice | CFMIP | as piSST but with SSTs and sea ice from abrupt-4xCO2 | 2 | none | no parent | AGCM | AER CHEM |  |  | 30 | no parent | As piSST, but with monthly-varying SSTs and sea-ice taken from years 111-140 of each model's own abrupt-4xCO2 experiment instead of from piControl
a4SSTice-4xCO2 | CFMIP | as piSST but with SSTs and sea ice from abrupt-4xCO2, and 4xCO2 seen by radiation and vegetation | 2 | none | no parent | AGCM | AER CHEM |  |  | 30 | no parent | As a4SSTice, but CO2 is quadrupled, and the increase in CO2 is seen by both the radiation scheme and vegetation
abrupt-0p5xCO2 | CFMIP | abrupt halving of CO2 | 2 | none | piControl | AOGCM | AER CHEM BGC |  |  | 150 | CMIP | Identical to the DECK abrupt-4xCO2, but at 0.5xCO2
abrupt-2xCO2 | CFMIP | abrupt doubling of CO2 | 2 | none | piControl | AOGCM | AER CHEM BGC |  |  | 150 | CMIP | Identical to the DECK abrupt-4xCO2, but at 2xCO2
abrupt-4xCO2 | CMIP | abrupt quadrupling of CO2 | 1 | none | piControl | AOGCM | AER CHEM BGC |  |  | 150 | CMIP | DECK: abrupt-4xCO2
abrupt-solm4p | CFMIP | abrupt 4% decrease in solar constant | 2 | none | piControl | AOGCM | AER CHEM BGC |  |  | 150 | CMIP | Conceptually similar to abrupt 4xCO2 DECK experiment, except that the solar constant rather than CO2 is abruptly reduced by 4%
abrupt-solp4p | CFMIP | abrupt 4% increase in solar constant | 2 | none | piControl | AOGCM | AER CHEM BGC |  |  | 150 | CMIP | Conceptually similar to abrupt 4xCO2 DECK experiment, except that the solar constant rather than CO2 is abruptly increased by 4%
amip | CMIP | AMIP | 1 | none | no parent | AGCM | AER CHEM BGC | 1979 | 2014 | 36 | no parent | DECK: AMIP
amip-4xCO2 | CFMIP | AMIP SSTs with 4xCO2 | 1 | none | no parent | AGCM | AER CHEM | 1979 | 2014 | 36 | no parent | As CMIP5/CFMIP-2 amip4xCO2 experiment. AMIP experiment where SSTs are held at control values and the CO2 seen by the radiation scheme is quadrupled
amip-TIP | GMMIP | same as "amip" run, but surface elevations of the Tibetan-Iranian Plateau and Himalayas reduced to 500m | 3 | none | no parent | AGCM | AER CHEM BGC | 1979 | 2014 | 36 | no parent | The topography of the TIP is modified by setting surface elevations to 500m; to understand the combined thermal and mechanical forcing of the TIP. Same model as DECK
amip-TIP-nosh | GMMIP | same as "amip" run, but sensible heat not allowed for elevations of the Tibetan-Iranian Plateau and Himalayas above 500m | 3 | none | no parent | AGCM | AER CHEM BGC | 1979 | 2014 | 36 | no parent | Surface sensible heat released at the elevation above 500m over the TIP is not allowed to heat the atmosphere. Same model as DECK
amip-a4SST-4xCO2 | CFMIP | as AMIP but with warming pattern from abrupt-4xCO2 added to SSTs and 4xCO2 seen by radiation and vegetation | 2 | none | no parent | AGCM | AER CHEM | 1979 | 2014 | 36 | no parent | Same as amip, but a patterned SST anomaly is applied on top of the monthly-varying amip SSTs. This anomaly is a monthly climatology, taken from each model's own abrupt-4xCO2 run minus piControl (using the mean of years 111-140 of abrupt-4xCO2, and the parallel 30-year section of piControl). CO2 is quadrupled, and the increase in CO2 is seen by both the radiation scheme and vegetation
amip-climSIC | PAMIP | AMIP with climatological SIC | 3 | none | amip | AGCM | AER CHEM BGC | 1979 | 2014 | 36 | CMIP | PA5.2: investigate role of transient SST in recent climate change
amip-climSST | PAMIP | AMIP with climatological SST | 3 | none | amip | AGCM | AER CHEM BGC | 1979 | 2014 | 36 | CMIP | PA5.1: investigate role of transient sea ice in recent climate change
amip-future4K | CFMIP | AMIP with patterned 4K SST increase | 1 | none | no parent | AGCM | AER CHEM | 1979 | 2014 | 36 | no parent | As CMIP5/CFMIP-2 amipFuture experiment. AMIP experiment where SSTs are subject to a composite SST warming pattern derived from coupled models, scaled to an ice-free ocean mean of 4K
amip-hist | GMMIP | AMIP-style simulation covering the period 1870-2014 | 1 | none | no parent | AGCM | AER CHEM BGC | 1870 | 2014 | 145 | no parent | Extended AMIP run that covers 1870-2014. All natural and anthropogenic historical forcings as used in CMIP6 Historical Simulation will be included. AGCM resolution as CMIP6 Historical Simulation. The HadISST data will be used
amip-hld | GMMIP | same as "amip" run, but surface elevations of the East African Highlands in Africa, Sierra Madre in N. America and Andes in S. America reduced to 500m | 3 | none | no parent | AGCM | AER CHEM BGC | 1979 | 2014 | 36 | no parent | The topography of the highlands in Africa, N. America and S. America TP is modified by setting surface elevations to a certain height (500m). Same model as DECK
amip-lfmip-pObs | LS3MIP | prescribed land (from pseudo-observations) and AMIP SSTs | 2 | none | no parent | AGCM | AER CHEM BGC | 1979 | 2014 | 36 | no parent | Land-hist land conditions; AMIP SSTs
amip-lfmip-pdLC | LS3MIP | prescribed modern land surface climatology from historical, prescribed SST and sea-ice from historical plus scenario runs | 2 | none | no parent | AGCM | AER CHEM BGC | 1979 | 2014 | 36 | no parent | Scenario forced experiment with prescribed land surface climatology derived from modern conditions from the first historical ensemble member (1980-2014). SST and sea-ice from the first ensemble members of the historical and ssp585 experiments
amip-lfmip-rmLC | LS3MIP | prescribed land surface climatology from historical plus scenario 30yr running mean, prescribed SST and sea-ice from historical plus scenario runs | 2 | none | no parent | AGCM | AER CHEM BGC | 1979 | 2014 | 36 | no parent | Scenario forced experiment with prescribed land surface climatology derived from 30yr running mean from the first ensemble members of the historical and ssp585 experiments. SST and sea-ice from the first ensemble members of the historical and ssp585 experiments
amip-lwoff | CFMIP | AMIP experiment with longwave cloud-radiative effects off | 2 | none | no parent | AGCM | AER CHEM | 1979 | 2014 | 36 | no parent | As amip experiment, but with cloud-radiative effects switched off in the LW radiation code
amip-m4K | CFMIP | AMIP with uniform 4K SST decrease | 2 | none | no parent | AGCM | AER CHEM | 1979 | 2014 | 36 | no parent | As amip experiment but SSTs are subject to a uniform cooling of 4K
amip-p4K | CFMIP | AMIP with uniform 4K SST increase | 1 | none | no parent | AGCM | AER CHEM | 1979 | 2014 | 36 | no parent | As CMIP5/CFMIP-2 amip4K experiment. AMIP experiment where SSTs are subject to a uniform warming of 4K
amip-p4K-lwoff | CFMIP | AMIP experiment with uniform 4K SST increase and with longwave cloud radiative effects off | 2 | none | no parent | AGCM | AER CHEM | 1979 | 2014 | 36 | no parent | As amip-p4K experiment, but with cloud-radiative effects switched off in the LW radiation code
amip-piForcing | CFMIP | AMIP SSTs with pre-industrial anthropogenic and natural forcing | 2 | none | no parent | AGCM | AER CHEM | 1870 | 2014 | 145 | no parent | Identical to standard AMIP experiment but from 1870-present with constant pre-industrial forcing levels (anthropogenic and natural)
aqua-4xCO2 | CFMIP | aquaplanet with control SST and 4xCO2 | 1 | none | no parent | AGCM | AER CHEM |  |  | 10 | no parent | Extended version of CMIP5/CFMIP-2 aqua4xCO2 experiment. Aquaplanet experiment where SSTs are held at control values and the CO2 seen by the radiation scheme is quadrupled
aqua-control | CFMIP | aquaplanet control | 1 | none | no parent | AGCM | AER CHEM |  |  | 10 | no parent | Extended version of CMIP5/CFMIP-2 aquaControl experiment. Aquaplanet (no land) experiment with no seasonal cycle forced with specified zonally symmetric SSTs
aqua-control-lwoff | CFMIP | aquaplanet control with longwave cloud radiative effects off | 2 | none | no parent | AGCM | AER CHEM |  |  | 10 | no parent | As aqua-control experiment, but with cloud-radiative effects switched off in the LW radiation code
aqua-p4K | CFMIP | aquaplanet with uniform 4K SST increase | 1 | none | no parent | AGCM | AER CHEM |  |  | 10 | no parent | Extended version of CMIP5/CFMIP-2 aqua4K experiment. Aquaplanet experiment where SSTs are subject to a uniform warming of 4K
aqua-p4K-lwoff | CFMIP | aquaplanet with uniform 4K SST increase and with longwave cloud radiative effects off | 2 | none | no parent | AGCM | AER CHEM |  |  | 10 | no parent | As aqua-p4K experiment, but with cloud-radiative effects switched off in the LW radiation code
control-1950 | HighResMIP | coupled control with fixed 1950's forcing (HighResMIP equivalent of pre-industrial control) | 2 | none | spinup-1950 | AOGCM | AER |  |  | 100 | HighResMIP | Coupled integrations with constant 1950"s forcing
control-slab | VolMIP | control with slab ocean | 3 | none | no parent | AGCM SLAB | AER CHEM BGC |  |  | 30 | no parent | slab control run for volc-pinatubo-slab
dcppA-assim | DCPP | Assimilation run paralleling the historical simulation, which may be used to generate hindcast initial conditions | 2 | none | no parent | AOGCM | AER CHEM BGC | before 1961 | 2016 | 56 | no parent | A2.3 Assimilation runs used to generate initial conditions for hindcasts
dcppA-hindcast | DCPP | hindcast initialized based on observations and using historical forcing | 1 | s1960 s1961 s1962 s1963 s1964 s1965 s1966 s1967 s1968 s1969 s1970 s1971 s1972 s1973 s1974 s1975 s1976 s1977 s1978 s1979 s1980 s1981 s1982 s1983 s1984 s1985 s1986 s1987 s1988 s1989 s1990 s1991 s1992 s1993 s1994 s1995 s1996 s1997 s1998 s1999 s2000 s2001 s2002 s2003 s2004 s2005 s2006 s2007 s2008 s2009 s2010 s2011 s2012 s2013 s2014 s2015 s2016 s2017 s2018 s2019 | no parent dcppA-assim | AOGCM | AER CHEM BGC | a year in the range 1960-2019 | 5 - 10 years after start year | 5 | no parent DCPP | A1 (and A2.1, A3.1, and A3.2) Decadal hindcasts begun near the end of each year from 1960 to 2019, or every other year at minimum. First full hindcast year follows start year (e.g., for s1960, first full hindcast year is 1961)
dcppA-hindcast-niff | DCPP | hindcast initialized based on observations but without using knowledge of subsequent historical forcing | 4 | s1960 s1961 s1962 s1963 s1964 s1965 s1966 s1967 s1968 s1969 s1970 s1971 s1972 s1973 s1974 s1975 s1976 s1977 s1978 s1979 s1980 s1981 s1982 s1983 s1984 s1985 s1986 s1987 s1988 s1989 s1990 s1991 s1992 s1993 s1994 s1995 s1996 s1997 s1998 s1999 s2000 s2001 s2002 s2003 s2004 s2005 s2006 s2007 s2008 s2009 s2010 s2011 s2012 s2013 s2014 s2015 s2016 s2017 s2018 s2019 | no parent dcppA-assim | AOGCM | AER CHEM BGC | a year in the range 1960-2019 | 5 - 10 years after start year | 5 | no parent DCPP | A4.1 Decadal hindcasts begun near the end of each year from 1960 to 2019, or every other year at minimum, but with no information from the future. First full hindcast year follows start year (e.g., for s1960, first full hindcast year is 1961)
dcppA-historical-niff | DCPP | hindcast initialized from historical climate simulation but without using knowledge of subsequent historical forcing | 4 | s1960 s1961 s1962 s1963 s1964 s1965 s1966 s1967 s1968 s1969 s1970 s1971 s1972 s1973 s1974 s1975 s1976 s1977 s1978 s1979 s1980 s1981 s1982 s1983 s1984 s1985 s1986 s1987 s1988 s1989 s1990 s1991 s1992 s1993 s1994 s1995 s1996 s1997 s1998 s1999 s2000 s2001 s2002 s2003 s2004 s2005 s2006 s2007 s2008 s2009 s2010 s2011 s2012 s2013 s2014 s2015 s2016 s2017 s2018 s2019 | historical | AOGCM | AER CHEM BGC | a year in the range 1960-2019 | 5 - 10 years after start year | 5 | CMIP | A4.2 Hindcasts initialized from historical climate simulations as in DCPP-A2.2, but with no information from the future. First full hindcast year follows start year (e.g., for s1960, first full hindcast year is 1961)
dcppB-forecast | DCPP | forecast initialized from observations with forcing from ssp245 | 1 | s2017 s2018 s2019 s2020 s2021 s2022 s2023 s2024 s2025 s2026 s2027 s2028 s2029 | no parent dcppA-assim | AOGCM | AER CHEM BGC | a year in the range 2017-2029 | 5 years after start year | 5 | no parent DCPP | B1 (and B2.1, B2.2) Ongoing decadal forecasts. First full forecast year follows start year (e.g., for s2017, first full forecast year is 2018)
dcppC-amv-ExTrop-neg | DCPP | Idealized climate impact of negative extratropical AMV anomaly pattern | 2 | none | piControl | AOGCM | AER CHEM BGC |  |  | 10 | CMIP | C1.7 Mechanisms and predictability of the hiatus and of similar long timescale variations of both signs
dcppC-amv-ExTrop-pos | DCPP | Idealized climate impact of positive extratropical AMV anomaly pattern | 2 | none | piControl | AOGCM | AER CHEM BGC |  |  | 10 | CMIP | C1.7Mechanisms and predictability of the hiatus and of similar long timescale variations of both signs
dcppC-amv-Trop-neg | DCPP | Idealized climate impact of negative tropical AMV anomaly pattern | 2 | none | piControl | AOGCM | AER CHEM BGC |  |  | 10 | CMIP | C1.8 Mechanisms and predictability of the hiatus and of similar long timescale variations of both signs
dcppC-amv-Trop-pos | DCPP | idealized positive tropical AMV anomaly pattern | 2 | none | piControl | AOGCM | AER CHEM BGC |  |  | 10 | CMIP | C1.8 Mechanisms and predictability of the hiatus and of similar long timescale variations of both signs
dcppC-amv-neg | DCPP | Idealized climate impact of negative AMV anomaly pattern | 1 | none | piControl | AOGCM | AER CHEM BGC |  |  | 10 | CMIP | C1.3 Mechanisms and predictability of the hiatus and of similar long timescale variations of both signs
dcppC-amv-pos | DCPP | Idealized climate impact of positive AMV anomaly pattern | 1 | none | piControl | AOGCM | AER CHEM BGC |  |  | 10 | CMIP | C1.2 Mechanisms and predictability of the hiatus and of similar long timescale variations of both signs
dcppC-atl-control | DCPP | Idealized Atlantic control | 1 | none | piControl | AOGCM | AER CHEM BGC |  |  | 10 | CMIP | C1.1 Mechanisms and predictability of the hiatus and of similar long timescale variations of both signs
dcppC-atl-pacemaker | DCPP | pacemaker Atlantic experiment | 3 | s1910 s1920 s1950 | historical | AOGCM | AER CHEM BGC | 1910, 1920 or 1950 | 2014 | 65 | CMIP | C1.11 Mechanisms and predictability of the hiatus and of similar long timescale variations of both signs
dcppC-atl-spg | DCPP | predictability of 1990s warming of Atlantic sub-polar gyre | 3 | s1992 s1993 s1994 s1995 s1996 s1997 s1998 s1999 | no parent | AOGCM | AER CHEM BGC | A year in the range 1992-1999 | 5 - 10 years after start year | 5 | no parent | C2.1 (and C2.2) Mechanisms and predictability of the hiatus and of similar long timescale variations of both signs. First full hindcast year follows start year (e.g., for s1992, first full hindcast year is 1993)
dcppC-forecast-addAgung | DCPP | 2015 forecast with added Agung forcing | 3 | s2014 | no parent dcppA-assim | AOGCM | AER CHEM BGC | 2014 | 5 - 10 years after start year | 5 | no parent DCPP | C3.4 Effects of volcanoes on decadal prediction and predictability of forced and internal variability components. First full hindcast year is 2015
dcppC-forecast-addElChichon | DCPP | 2015 forecast with added El Chichon forcing | 3 | s2014 | no parent dcppA-assim | AOGCM | AER CHEM BGC | 2014 | 5 - 10 years after start year | 5 | no parent DCPP | C3.5 Effects of volcanoes on decadal prediction and predictability of forced and internal variability components. First full hindcast year is 2015
dcppC-forecast-addPinatubo | DCPP VolMIP | 2015 forecast with added Pinatubo forcing | 1 | s2014 | no parent dcppA-assim | AOGCM | AER CHEM BGC | 2014 | 5 - 10 years after start year | 5 | no parent DCPP | C3.6 Effects of volcanoes on decadal prediction and predictability of forced and internal variability components. First full hindcast year is 2015
dcppC-hindcast-noAgung | DCPP | hindcast but with only background volcanic forcing to be the same as that used in the 2015 forecast | 2 | s1962 | no parent dcppA-assim | AOGCM | AER CHEM BGC | 1962 | 5 - 10 years after start year | 5 | no parent DCPP | C3.3 Effects of volcanoes on decadal prediction and predictability of forced and internal variability components. First full hindcast year is 1962
dcppC-hindcast-noElChichon | DCPP | hindcast but with only background volcanic forcing to be the same as that used in the 2015 forecast | 2 | s1981 | no parent dcppA-assim | AOGCM | AER CHEM BGC | 1981 | 5 - 10 years after start year | 5 | no parent DCPP | C3.2 Effects of volcanoes on decadal prediction and predictability of forced and internal variability components. First full hindcast year is 1982
dcppC-hindcast-noPinatubo | DCPP | hindcast but with only background volcanic forcing to be the same as that used in the 2015 forecast | 1 | s1990 | no parent dcppA-assim | AOGCM | AER CHEM BGC | 1990 | 5 - 10 years after start year | 5 | no parent DCPP | C3.1 Effects of volcanoes on decadal prediction and predictability of forced and internal variability components. First full hindcast year is 1991
dcppC-ipv-NexTrop-neg | DCPP | idealized negative northern extratropical IPV anomaly pattern | 2 | none | piControl | AOGCM | AER CHEM BGC |  |  | 10 | CMIP | C1.9 and predictability of the hiatus and of similar long timescale variations of both signs
dcppC-ipv-NexTrop-pos | DCPP | idealized positive northern extratropical IPV anomaly pattern | 2 | none | piControl | AOGCM | AER CHEM BGC |  |  | 10 | CMIP | C1.9 Mechanisms and predictability of the hiatus and of similar long timescale variations of both signs
dcppC-ipv-neg | DCPP | idealized negative IPV anomaly pattern | 1 | none | piControl | AOGCM | AER CHEM BGC |  |  | 10 | CMIP | C1.6 Mechanisms and predictability of the hiatus and of similar long timescale variations of both signs
dcppC-ipv-pos | DCPP | idealized positive IPV anomaly pattern | 1 | none | piControl | AOGCM | AER CHEM BGC |  |  | 10 | CMIP | C1.5 Mechanisms and predictability of the hiatus and of similar long timescale variations of both signs
dcppC-pac-control | DCPP | idealized Pacific control | 1 | none | piControl | AOGCM | AER CHEM BGC |  |  | 10 | CMIP | C1.4 Mechanisms and predictability of the hiatus and of similar long timescale variations of both signs
dcppC-pac-pacemaker | DCPP | pacemaker Pacific experiment | 3 | s1910 s1920 s1950 | historical | AOGCM | AER CHEM BGC | 1910, 1920 or 1950 | 2014 | 65 | CMIP | C1.10 Mechanisms and predictability of the hiatus and of similar long timescale variations of both signs. First full hindcast year is 2015
deforest-globe | LUMIP | idealized transient global deforestation | 1 | none | piControl | AOGCM | AER CHEM BGC |  |  | 81 | CMIP | Idealized deforestation experiment, 20 million km2 forest removed linearly over a period of 50 years, with an additional 30 years with no specified change in forest cover; all other forcings held constant
esm-1pct-brch-1000PgC | C4MIP CDRMIP | zero emissions simulation branched from 1% run after 1000 PgC cumulative emission | 2 | none | 1pctCO2 esm-1pctCO2 | AOGCM BGC | AER CHEM |  |  | 100 | CMIP C4MIP | A zero-emissions simulation (fully interactive CO2; emissions-driven configuration), initiated from the point in the 1pctCO2 experiment when the cumulative carbon emissions reach 1000 PgC
esm-1pct-brch-2000PgC | C4MIP CDRMIP | zero emissions simulation branched from 1% run after 2000 PgC cumulative emission | 3 | none | 1pctCO2 esm-1pctCO2 | AOGCM BGC | AER CHEM |  |  | 100 | CMIP C4MIP | A zero-emissions simulation (fully interactive CO2; emissions-driven configuration), initiated from the point in the 1pctCO2 experiment when the cumulative carbon emissions reach 2000 PgC
esm-1pct-brch-750PgC | C4MIP CDRMIP | zero emissions simulation branched from 1% run after 750 PgC cumulative emission | 3 | none | 1pctCO2 esm-1pctCO2 | AOGCM BGC | AER CHEM |  |  | 100 | CMIP C4MIP | A zero-emissions simulation (fully interactive CO2; emissions-driven configuration), initiated from the point in the 1pctCO2 experiment when the cumulative carbon emissions reach 750 PgC
esm-1pctCO2 | C4MIP CDRMIP | emissions driven 1% run | 3 | none | esm-piControl | AOGCM BGC | AER CHEM |  |  | 150 | CMIP | An emissions-driven simulation (fully interactive CO2), initiated from the esm-piControl using CO2 emissions diagnosed from the 1pctCO2 experiment so that the emissions-driven run replicates as closely as possible the 1pctCO2 concentration profile
esm-bell-1000PgC | C4MIP CDRMIP | emissions driven 1000PgC bell-curve | 3 | none | esm-piControl | AOGCM BGC | AER CHEM |  |  | 200 | CMIP | An emissions-driven simulation (fully interactive CO2), initiated from esm-piControl using CO2 emissions, amounting to 1000 PgC, following a bell-shape curve for 100 years followed by zero-emissions for 100 years
esm-bell-2000PgC | C4MIP CDRMIP | emissions driven 2000PgC bell-curve | 3 | none | esm-piControl | AOGCM BGC | AER CHEM |  |  | 200 | CMIP | An emissions-driven simulation (fully interactive CO2), initiated from esm-piControl using CO2 emissions, amounting to 2000 PgC, following a bell-shape curve for 100 years followed by zero-emissions for 100 years
esm-bell-750PgC | C4MIP CDRMIP | emissions driven 750PgC bell-curve | 3 | none | esm-piControl | AOGCM BGC | AER CHEM |  |  | 200 | CMIP | An emissions-driven simulation (fully interactive CO2), initiated from esm-piControl using CO2 emissions, amounting to 750 PgC, following a bell-shape curve for 100 years followed by zero-emissions for 100 years
esm-hist | CMIP | all-forcing simulation of the recent past with atmospheric CO2 concentration calculated | 1 | none | esm-piControl | AOGCM BGC | AER CHEM | 1850 | 2014 | 165 | CMIP | CMIP6 historical (CO2 emission-driven)
esm-hist-ext | CMIP | post-2014 all-forcing simulation with atmospheric CO2 concentration calculated | 2 | none | esm-hist | AOGCM BGC | AER CHEM | 2015 | present | 1 | CMIP | Extension beyond 2014 of the CMIP6 historical (CO2 emission-driven)
esm-past1000 | PMIP | last millennium experiment with interactive carbon cycle | 3 | none | no parent | AOGCM BGC | AER CHEM | 850 | 1849 | 1000 | no parent | Parallel experiment to past1000, but for model set-ups with interactive carbon cycle. Main forcings: trace gases, volcanoes, solar variability, land-use
esm-pi-CO2pulse | CDRMIP | pulse addition of 100 Gt carbon to pre-industrial atmosphere | 1 | none | esm-piControl | AOGCM BGC | AER CHEM |  |  | 100 | CMIP | 100 Gt C instantly added (positive pulse) to a pre-industrial atmosphere (part of the CDR-pi-pulse experiment)
esm-pi-cdr-pulse | CDRMIP | pulse removal of 100 Gt carbon from pre-industrial atmosphere | 1 | none | esm-piControl | AOGCM BGC | AER CHEM |  |  | 100 | CMIP | 100 Gt C instantly removed (negative pulse) from a pre-industrial atmosphere (part of the CDR-pi-pulse experiment)
esm-piControl | CMIP | pre-industrial control simulation with CO2 concentration calculated | 1 | none | esm-piControl-spinup | AOGCM BGC | AER CHEM |  |  | 500 | CMIP | DECK: control (emission-driven)
esm-piControl-spinup | CMIP | pre-industrial control simulation with CO2 concentration calculated (spin-up) | 2 | none | no parent | AOGCM BGC | AER CHEM |  |  | 100 | no parent | DECK: spin-up portion of the control (emission-driven)
esm-ssp534-over | CDRMIP | emission-driven SSP5-3.4-OS scenario | 2 | none | esm-ssp585 | AOGCM BGC | AER CHEM | 2040 | 2100 or 2300 | 61 | C4MIP | CO2 emissions driven SSP5-3.4 overshoot scenario simulation optionally extending to year 2300 (part of the CDR-overshoot experiment)
esm-ssp585 | C4MIP | emission-driven RCP8.5 based on SSP5 | 1 | none | esm-hist | AOGCM BGC | AER CHEM | 2015 | 2100 | 86 | CMIP | Emissions-driven future scenario simulation
esm-ssp585-ocn-alk | CDRMIP | emission-driven SSP5-8.5 scenario but with ocean alkalinization from year 2020 onward | 2 | none | esm-ssp585 | AOGCM BGC | AER CHEM | 2020 | 2100 or 2300 | 81 | C4MIP | emission driven SSP5-8.5 scenario with 0.14 Pmol/yr alkalinity added to ice free ocean surface waters from 2020 optionally extended from 2100 to 2300 (part of the CDR-ocean-alk experiment)
esm-ssp585-ocn-alk-stop | CDRMIP | emission-driven SSP5-8.5 scenario with alkalinization terminated in year 2070 | 3 | none | esm-ssp585-ocn-alk | AOGCM BGC | AER CHEM | 2070 | 2100 | 31 | CDRMIP | Simulation of abrupt termination of ocean alkalinsation in 2070 during an emission driven SSP5-8.5 scenario (part of the CDR-ocean-alk experiment)
esm-ssp585-ssp126Lu | LUMIP | emissions-driven SSP5-8.5 with SSP1-2.6 land use | 1 | none | esm-hist | AOGCM BGC | AER CHEM | 2015 | 2100 | 86 | CMIP | Additional land use policy sensitivity simulation for high radiative forcing scenario, keep all forcings the same as in C4MIP esmssp5-8.5 scenario except use SSP1-2.6 land use; emission driven
esm-ssp585-ssp126Lu-ext | CDRMIP | extension of the LUMIP emissions-driven simulation following SSP5-8.5 with SSP1-2.6 land use | 2 | none | esm-ssp585-ssp126Lu | AOGCM BGC | AER CHEM | 2101 | 2300 | 200 | LUMIP | Long term extension of CO2 emissions driven SSP5-8.5 with SSP1-2.6 land use forcing (part of the CDR-afforestation experiment)
esm-ssp585ext | CDRMIP | emission-driven long-term extension of the SSP5-8.5 scenario | 2 | none | esm-ssp585 | AOGCM BGC | AER CHEM | 2101 | 2300 | 200 | C4MIP | Long term extension of CO2 emissions driven SSP5-8.5 scenario (used in the CDR-afforestation and CDR-ocean-alk experiments)
esm-yr2010CO2-CO2pulse | CDRMIP | instantaneous 100 Gt C addition to an industrial era atmosphere | 3 | none | esm-yr2010CO2-control | AOGCM BGC | AER CHEM | 2015 | 2115 | 101 | CDRMIP | Upon initialization from end of year 2015 of esm-yr2010CO2-control instantaneously introduce 100 Gt C ("positive pulse"; part of the CDR-yr2010-pulse experiment)
esm-yr2010CO2-cdr-pulse | CDRMIP | instantaneous 100 Gt C removal from industrial era atmosphere | 3 | none | esm-yr2010CO2-control | AOGCM BGC | AER CHEM | 2015 | 2115 | 101 | CDRMIP | Upon initialization from end of year 2015 of esm-yr2010CO2-control instantaneously remove 100 Gt C ("negative pulse"; part of the CDR-yr2010-pulse experiment
esm-yr2010CO2-control | CDRMIP | historical emissions followed by fixed 2010 emissions (both model-diagnosed) | 3 | none | esm-piControl | AOGCM BGC | AER CHEM | 1850 | 2115 | 266 | CDRMIP | Forced with CO2 emissions diagnosed from historical and yr2010CO2 simulations and all other forcings the same as in that simulation (part of the CDR-yr2010-pulse experiment)
esm-yr2010CO2-noemit | CDRMIP | branches from esm-yr2010CO2-control with zero emissions | 3 | none | esm-yr2010CO2-control | AOGCM BGC | AER CHEM | 2015 | 2115 | 101 | CDRMIP | Upon initialization from end of year 2015 of esm-yr2010-control CO2 emissions are fixed at zero; all other forcing fixed at 2010 level (part of the CDR-yr2010-pulse experiment)
faf-all | FAFMIP | control plus perturbative surface fluxes of momentum, heat and water into ocean | 2 | none | piControl | AOGCM | AER CHEM BGC |  |  | 70 | CMIP | 1xCO2 experiment, parallel to piControl, forced over the ocean simultaneously by surface windstress (as in the wind experiment), net heat flux (as in the heat experiment) and net freshwater flux (as in the water experiment) anomalies obtained from the CMIP5 ensemble mean of 1pctCO2 experiments at the time of 2xCO2, using a passive tracer to prevent negative climate feedback on the heat flux applied
faf-antwater-stress | FAFMIP | control plus perturbative surface fluxes of momentum and freshwater into ocean, the latter around the coast of Antarctica only | 2 | none | piControl | AOGCM | AER CHEM BGC |  |  | 70 | CMIP | 1xCO2 experiment, parallel to piControl, forced over the ocean with the momentum flux perturbation field of faf-stress and a surface freshwater flux of 0.1 Sv in total to be applied uniformly around the coast of Antarctica in whatever way is most suitable in the model
faf-heat | FAFMIP | control plus perturbative surface flux of heat into ocean | 1 | none | piControl | AOGCM | AER CHEM BGC |  |  | 70 | CMIP | 1xCO2 experiment, parallel to piControl, forced over the ocean by surface net heat flux anomalies obtained from the CMIP5 ensemble mean of 1pctCO2 experiments at the time of 2xCO2, using a passive tracer to prevent negative climate feedback on the heat flux applied
faf-heat-NA0pct | FAFMIP | control plus perturbative surface flux of heat into ocean | 2 | none | piControl | AOGCM | AER CHEM BGC |  |  | 70 | CMIP | 1xCO2 experiment, parallel to piControl, forced over the ocean by the same method and with the same surface net heat flux perturbation field as in faf-heat, except that within part of the North Atlantic ocean the perturbation is zero
faf-heat-NA50pct | FAFMIP | control plus perturbative surface flux of heat into ocean | 1 | none | piControl | AOGCM | AER CHEM BGC |  |  | 70 | CMIP | 1xCO2 experiment, parallel to piControl, forced over the ocean by the same method and with the same surface net heat flux perturbation field as in faf-heat, except that within part of the North Atlantic ocean the perturbation is multiplied by 0.5
faf-passiveheat | FAFMIP | control plus surface flux of passive heat tracer into ocean | 2 | none | piControl | AOGCM | AER CHEM BGC |  |  | 70 | CMIP | 1xCO2 experiment, parallel to piControl, with a flux of passive tracer added at the ocean surface at the same rate as the surface net heat flux anomaly applied in the FAFMIP heat experiment
faf-stress | FAFMIP | control plus perturbative surface flux of momentum into ocean | 1 | none | piControl | AOGCM | AER CHEM BGC |  |  | 70 | CMIP | 1xCO2 experiment, parallel to piControl, forced over the ocean by surface windstress anomalies obtained from the CMIP5 ensemble mean of 1pctCO2 experiments at the time of 2xCO2
faf-water | FAFMIP | control plus perturbative surface flux of water into ocean | 1 | none | piControl | AOGCM | AER CHEM BGC |  |  | 70 | CMIP | 1xCO2 experiment, parallel to piControl, forced over the ocean by surface net freshwater flux anomalies obtained from the CMIP5 ensemble mean of 1pctCO2 experiments at the time of 2xCO2
futSST-pdSIC | PAMIP | Atmosphere time slice with future SST and present day SIC | 2 | none | amip | AGCM | AER CHEM BGC | 2000 | 2001 | 1 | CMIP | PA1.4: investigate role of SST in polar amplification
futureSST-4xCO2-solar | GeoMIP | year 100 SSTs from abrupt-4xCO2 with quadrupled CO2 and solar reduction | 2 | none | G1 | AGCM | AER CHEM |  |  | 10 | GeoMIP | Time slice at year 100 of G1ext to examine radiative forcing of abrupt-4xCO2 and G1
highres-future | HighResMIP | coupled future 2015-2050 using a scenario as close to CMIP5 RCP8.5 as possible within CMIP6 | 2 | none | hist-1950 | AOGCM | AER | 2015 | 2050 | 36 | HighResMIP | Coupled integrations with SSP5 forcing (nearest to CMIP5 RCP8.5 (as in highresSST-future)
highresSST-4xCO2 | HighResMIP | highresSST-present SST with 4xCO2 concentrations | 3 | none | highresSST-present | AGCM | AER | 1979 | 2014 | 36 | HighResMIP | Similar to CFMIP amip-4xCO2, SSTs are held at highresSST-present values and the CO2 seen by the radiation scheme is quadrupled
highresSST-LAI | HighResMIP | common LAI dataset within the highresSST-present experiment | 3 | none | highresSST-present | AGCM | AER | 1979 | 2014 | 36 | HighResMIP | Forced global atmosphere-land simulations as highresSST-present, but using an common LAI dataset across models
highresSST-future | HighResMIP | forced atmosphere experiment for 2015-2050 using SST/sea-ice derived from CMIP5 RCP8.5 simulations and a scenario as close to RCP8.5 as possible within CMIP6 | 3 | none | highresSST-present | AGCM | AER | 2015 | 2050 | 36 | HighResMIP | Extend highresSST-present to 2050 with agreed SSP5/RCP8.5 forcings (with option to extend further to 2100)
highresSST-p4K | HighResMIP | uniform 4K warming of highresSST-present SST | 3 | none | highresSST-present | AGCM | AER | 1979 | 2014 | 36 | HighResMIP | Similar to CFMIP amip-p4K, add a uniform warming of 4K to highresSST-present SSTs and run the experiment parallel to highresSST-present
highresSST-present | HighResMIP | forced atmosphere experiment for 1950-2014 | 1 | none | no parent | AGCM | AER | 1950 | 2014 | 65 | no parent | Forced global atmosphere-land simulations using daily 1/4 degree SST and sea-ice forcings, and aerosol optical properties (not emissions) to constrain model spread
highresSST-smoothed | HighResMIP | smoothed SST version of highresSST-present | 3 | none | highresSST-present | AGCM | AER | 1979 | 2014 | 36 | HighResMIP | Forced global atmosphere-land simulations as highresSST-present, but using smoothed SST to investigate impact of SST variability
hist-1950 | HighResMIP | coupled historical 1950-2014 | 2 | none | spinup-1950 | AOGCM | AER | 1950 | 2014 | 65 | HighResMIP | Coupled integrations with historic external forcings (as in highresSST-present)
hist-1950HC | AerChemMIP | historical forcing, but with1950s halocarbon concentrations; initialized in 1950 | 1 | none | historical | AOGCM AER CHEM | BGC | 1950 | 2014 | 65 | CMIP | Historical WMGHG concentrations and NTCF emissions, 1950 halocarbon concentrations, start 1950
hist-CO2 | DAMIP | historical CO2-only run | 3 | none | piControl | AOGCM | AER CHEM BGC | 1850 | 2020 | 171 | CMIP | Historical CO2-only run
hist-GHG | DAMIP | historical well-mixed GHG-only run | 1 | none | piControl | AOGCM | AER CHEM BGC | 1850 | 2020 | 171 | CMIP | Historical well-mixed GHG-only run. Models with interactive chemistry schemes should either turn off the chemistry or use a preindustrial climatology of stratospheric and tropospheric ozone in their radiation schemes. This will ensure that ozone is fixed in all these simulations, and simulated responses in models with and without coupled chemistry are comparable
hist-GHG-cmip5 | DAMIP | historical well-mixed GHG-only run (CMIP5-era historical [1850-2005] and RCP4.5 [2006-2020] forcing) | 3 | none | piControl-cmip5 | AOGCM | AER CHEM BGC | 1850 | 2020 | 171 | CMIP | historical well-mixed GHG-only run. Models with interactive chemistry schemes should either turn off the chemistry or use a preindustrial climatology of stratospheric and tropospheric ozone in their radiation schemes. This will ensure that ozone is fixed in all these simulations, and simulated responses in models with and without coupled chemistry are comparable (CMIP5-era historical [1850-2005] and RCP4.5 [2006-2020] forcing)
hist-aer | DAMIP | historical anthropogenic aerosols-only run | 1 | none | piControl | AOGCM | AER CHEM BGC | 1850 | 2020 | 171 | CMIP | historical anthropogenic aerosols-only run
hist-aer-cmip5 | DAMIP | historical anthropogenic aerosols-only run (CMIP5-era historical [1850-2005] and RCP4.5 [2006-2020] forcing) | 3 | none | piControl-cmip5 | AOGCM | AER CHEM BGC | 1850 | 2020 | 171 | CMIP | historical anthropogenic aerosols-only run (CMIP5-era historical [1850-2005] and RCP4.5 [2006-2020] forcing)
hist-all-aer2 | DAMIP | historical ALL-forcing run with alternate estimates of aerosol forcing | 3 | none | piControl | AOGCM | AER CHEM BGC | 1850 | 2020 | 171 | CMIP | Historical ALL forcing run with alternate estimates of aerosol concentrations/emissions
hist-all-nat2 | DAMIP | historical ALL-forcing run with alternate estimates of natural forcing | 3 | none | piControl | AOGCM | AER CHEM BGC | 1850 | 2020 | 171 | CMIP | Historical ALL forcing run with alternates estimate of solar and volcanic forcing
hist-bgc | C4MIP | biogeochemically-coupled version of the simulation of the recent past with CO2 concentration prescribed | 2 | none | piControl | AOGCM BGC | AER CHEM | 1850 | 2014 | 165 | CMIP | Concentration-driven historical simulation, biogeochemically-coupled
hist-nat | DAMIP | historical natural-only run | 1 | none | piControl | AOGCM | AER CHEM BGC | 1850 | 2020 | 171 | CMIP | Historical natural-only run
hist-nat-cmip5 | DAMIP | historical natural-only run (CMIP5-era historical [1850-2005] and RCP4.5 [2006-2020] forcing) | 3 | none | piControl-cmip5 | AOGCM | AER CHEM BGC | 1850 | 2020 | 171 | CMIP | historical natural-only run (CMIP5-era historical [1850-2005] and RCP4.5 [2006-2020] forcing)
hist-noLu | LUMIP | historical with no land-use change | 1 | none | piControl | AOGCM | AER CHEM BGC | 1850 | 2014 | 165 | CMIP | Same as CMIP6 historical but with land cover held at 1850, no human activity; concentration driven
hist-piAer | AerChemMIP | historical forcing, but with pre-industrial aerosol emissions | 2 | none | piControl | AOGCM AER | CHEM BGC | 1850 | 2014 | 165 | CMIP | Historical WMGHG, halocarbon concentrations and O3 precursor emissions, 1850 aerosol precursor emissions
hist-piNTCF | AerChemMIP | historical forcing, but with pre-industrial NTCF emissions | 1 | none | piControl | AOGCM AER | CHEM BGC | 1850 | 2014 | 165 | CMIP | Historical WMGHG and halocarbons concentrations, 1850 NTCF emissions
hist-resAMO | GMMIP | initialized from "historical" run year 1870 and SSTs in the AMO domain (0deg-70degN, 70degW-0deg) restored to AMIP SSTs with historical forcings | 2 | none | historical | AOGCM | AER CHEM BGC | 1870 | 2014 | 145 | CMIP | Pacemaker 20th century historical run that includes all forcing as used in CMIP6 Historical Simulation, and the observational historical SST is restored in the AMO domain (0deg-70degN, 70degW-0deg)
hist-resIPO | GMMIP | initialized from "historical" run year 1870 and SSTs in tropical lobe of the IPO domain (20degS-20degN, 175degE-75degW) restored to AMIP SSTs with historical forcings | 2 | none | historical | AOGCM | AER CHEM BGC | 1870 | 2014 | 145 | CMIP | Pacemaker 20th century historical run that includes all forcing as used in CMIP6 Historical Simulation, and the observational historical SST is restored in the tropical lobe of the IPO domain (20degS-20degN, 175degE-75degW)
hist-sol | DAMIP | historical solar-only run | 3 | none | piControl | AOGCM | AER CHEM BGC | 1850 | 2020 | 171 | CMIP | Historical solar-only transient simulation using settings from CMIP6 historical simulation but fixed GHG and ODS (1850 level)
hist-spAer-aer | RFMIP | historical simulation with specified anthropogenic aerosols, no other forcings | 2 | none | piControl | AOGCM | CHEM BGC | 1850 | 2014 | 165 | CMIP | Prescribed anthropogenic aerosol optical properties. Changes in aerosols only
hist-spAer-all | RFMIP | historical simulation with specified anthropogenic aerosols | 1 | none | piControl | AOGCM | CHEM BGC | 1850 | 2014 | 165 | CMIP | Prescribed anthropogenic aerosol optical properties. All forcings
hist-stratO3 | DAMIP | historical stratospheric ozone-only run | 2 | none | piControl | AOGCM | AER BGC | 1850 | 2020 | 171 | CMIP | Historical stratospheric ozone-only. In models with coupled chemistry, the chemistry scheme should be turned off, and the simulated ensemble mean monthly mean 3D stratospheric ozone concentrations from the CMIP6 historical simulations should be prescribed. Tropospheric ozone should be fixed at 3D long-term monthly mean piControl values, with a value of 100 ppbv ozone concentration in this piControl climatology used to separate the troposphere from the stratosphere. In models without coupled chemistry the same stratospheric ozone prescribed in the CMIP6 historical simulations should be prescribed. Stratospheric ozone concentrations will be provided by CCMI
hist-totalO3 | DAMIP | historical total ozone-only run | 3 | none | piControl | AOGCM | AER BGC | 1850 | 2020 | 171 | CMIP | Historical total ozone-only. In models with coupled chemistry, the chemistry scheme should be turned off, and the simulated ensemble mean monthly mean 3D ozone concentrations from the CMIP6 historical simulations should be prescribed through the depth of the atmosphere. In models without coupled chemistry the same ozone prescribed in the CMIP6 historical simulations should be prescribed
hist-volc | DAMIP | historical volcanic-only run | 3 | none | piControl | AOGCM | AER CHEM BGC | 1850 | 2020 | 171 | CMIP | Historical volcanic-only run
histSST | AerChemMIP | historical prescribed SSTs and historical forcing | 1 | none | piControl | AGCM AER | CHEM BGC | 1850 | 2014 | 165 | CMIP | Historical transient with SSTs prescribed from historical
histSST-1950HC | AerChemMIP | historical SSTs and historical forcing, but with 1950 halocarbon concentrations. Experiment is initialized from histSST (AerChemMIP) simulation from January 1950 | 1 | none | histSST | AGCM AER CHEM | BGC | 1950 | 2014 | 65 | AerChemMIP | Historical WMGHG concentrations and NTCF emissions, 1950 halocarbon concentrations
histSST-noLu | AerChemMIP | historical SSTs and historical forcing, but with pre-industrial LULCC | 1 | none | piControl | AGCM | AER CHEM BGC | 1850 | 2014 | 165 | CMIP | An uncoupled (atmosphere and land) experiment in which sea surface temperatures (SST) and sea ice concentrations (SICONC) are taken from historical (as in existing histSST experiment). All forcing agents to follow historical except LULCC. LULCC set to 1850 (exactly following hist-noLu prescription)
histSST-piAer | AerChemMIP | historical SSTs and historical forcing, but with pre-industrial aerosol emissions | 2 | none | piControl | AGCM AER | CHEM BGC | 1850 | 2014 | 165 | CMIP | Historical WMGHG, halocarbon concentrations and tropospheric ozone precursors emissions, 1850 aerosol precursor emissions, prescribed SSTs
histSST-piCH4 | AerChemMIP | historical SSTs and historical forcing, but with pre-industrial methane concentrations | 1 | none | piControl | AGCM AER CHEM | BGC | 1850 | 2014 | 165 | CMIP | Historical (non-CH4) WMGHG concentrations and NTCF emissions, 1850 CH4 concentrations
histSST-piN2O | AerChemMIP | historical SSTs and historical forcings, but with pre-industrial N2O concentrations | 2 | none | piControl | AGCM AER CHEM | BGC | 1850 | 2014 | 165 | CMIP | Historical (non-N2O) WMGHG concentrations and NTCF emissions, 1850 N2O concentrations
histSST-piNTCF | AerChemMIP | historical SSTs and historical forcing, but with pre-industrial NTCF emissions | 1 | none | piControl | AGCM AER | CHEM BGC | 1850 | 2014 | 165 | CMIP | Historical WMGHG concentrations and halocarbons emissions, 1850 NTCF emissions, prescribed SSTs
histSST-piO3 | AerChemMIP | historical SSTs and historical forcing, but with pre-industrial ozone precursor emissions | 2 | none | piControl | AGCM AER CHEM | BGC | 1850 | 2014 | 165 | CMIP | Historical WMGHG, halocarbon concentrations and aerosol precursor emissions, 1850 tropospheric ozone precursors emissions, prescribed SSTs
historical | CMIP | all-forcing simulation of the recent past | 1 | none | piControl past1000 past2k | AOGCM | AER CHEM BGC | 1850 | 2014 | 165 | CMIP PMIP | CMIP6 historical
historical-cmip5 | CMIP | all-forcing simulation of the recent past (CMIP5-era [1850-2005] forcing) | 2 | none | piControl-cmip5 | AOGCM | AER CHEM BGC | 1850 | 2005 | 156 | CMIP | CMIP5 historical experiment, using CMIP5-era [1850-2005] forcing
historical-ext | CMIP | post-2014 all-forcing simulation | 2 | none | historical | AOGCM | AER CHEM BGC | 2015 | present | 1 | CMIP | Extension beyond 2014 of the CMIP6 historical
historical-withism | ISMIP6 | historical with interactive ice sheet | 2 | none | piControl-withism | AOGCM ISM | AER CHEM BGC | 1850 | 2014 | 165 | ISMIP6 | Historical simulation that includes interactive ice sheets. Set up follows the historical experiment
ism-1pctCO2to4x-self | ISMIP6 | offline ice sheet model forced by ISM's own AOGCM 1pctCO2to4x output | 1 | none | ism-piControl-self | ISM |  |  |  | 350 | ISMIP6 | Idealized 1%/yr CO2 increase to 4xC02 over 140yrs and kept constant at 4xCO2 for an additional 200 to 400 yrs simulation with ice sheets forced "offline" with DECK 1pctCO2 using forcing from its own AOGCM
ism-1pctCO2to4x-std | ISMIP6 | offline ice sheet model forced by ISMIP6-specified AOGCM 1pctCO2to4x output | 1 | none | ism-pdControl-std | ISM |  |  |  | 350 | ISMIP6 | Idealized 1%/yr CO2 increase to 4xC02 over 140yrs and kept constant at 4xCO2 for an additional 200 to 400 yrs simulation with ice sheets forced "offline" with DECK 1pctCO2 using a standard forcing
ism-amip-std | ISMIP6 | offline ice sheet forced by ISMIP6-specified AGCM AMIP output | 3 | none | ism-ctrl-std | ISM |  | 1979 | 2014 | 36 | ISMIP6 | Offline ice sheet evolution for the last few decades forced by amip
ism-asmb-std | ISMIP6 | offline ice sheet forced by initMIP synthetic atmospheric experiment | 1 | none | ism-ctrl-std | ISM |  |  |  | 100 | ISMIP6 | Offline ice sheet simulation with synthetic atmospheric dataset to explore the uncertainty in sea level due to ice sheet initialization
ism-bsmb-std | ISMIP6 | offline ice sheet forced by initMIP synthetic oceanic experiment | 1 | none | ism-ctrl-std | ISM |  |  |  | 100 | ISMIP6 | Offline ice sheet simulation with synthetic oceanic dataset to explore the uncertainty in sea level due to ice sheet initialization
ism-ctrl-std | ISMIP6 | offline ice sheet model initMIP control | 1 | none | no parent | ISM |  |  |  | 100 | no parent | Offline ice sheet control run for the initMIP experiment that explores the uncertainty in sea level due to ice sheet initialization
ism-historical-self | ISMIP6 | offline ice sheet forced by ISM's own AOGCM historical output | 2 | none | ism-piControl-self | ISM |  | 1850 | 2014 | 165 | ISMIP6 | Historical simulation using "offline" ice sheet models. Forcing for ice sheet model is from its own AOGCM
ism-historical-std | ISMIP6 | offline ice sheet forced by ISMIP6-specified AOGCM historical output | 2 | none | ism-pdControl-std | ISM |  | 1850 | 2014 | 165 | ISMIP6 | Historical simulation using "offline" ice sheet models. Forcing for ice sheet model is the standard dataset based on CMIP6 AOGCM historical
ism-lig127k-std | ISMIP6 | offline ice sheet forced by ISMIP6-specified AGCM last interglacial output | 3 | none | no parent | ISM |  |  |  | 20000 | no parent | Last interglacial simulation of ice sheet evolution driven by PMIP lig127k
ism-pdControl-std | ISMIP6 | offline ice sheet forced by ISMIP6-specified AOGCM pdControl output | 1 | none | no parent | ISM |  |  |  | 100 | no parent | Present-day control simulation for "offline" ice sheets
ism-piControl-self | ISMIP6 | offline ice sheet forced by ISM's own AOGCM piControl output | 1 | none | no parent | ISM |  |  |  | 500 | no parent | Pre-industrial control simulation for "offline" ice sheets
ism-ssp585-self | ISMIP6 | offline ice sheet forced by ISM's own AOGCM ssp585 output | 2 | none | ism-historical-self | ISM |  | 2015 | 2100 or 2300 | 86 | ISMIP6 | Future climate ScenarioMIP SSP5-8.5 simulation using "offline" ice sheet models. Forcing for ice sheet model is from its own AOGCM
ism-ssp585-std | ISMIP6 | offline ice sheet forced by ISMIP6-specified AOGCM ssp585 output | 2 | none | ism-historical-std | ISM |  | 2015 | 2100 or 2300 | 86 | ISMIP6 | Future climate ScenarioMIP SSP5-8.5 simulation using "offline" ice sheet models. Forcing for ice sheet model is the standard dataset based on ScenarioMIP ssp585
land-cCO2 | LUMIP | historical land-only constant CO2 | 2 | none | no parent | LAND BGC |  | 1850 or 1700 | 2014 | 165 | no parent | Same as land-hist except with CO2 held constant
land-cClim | LUMIP | historical land-only constant climate | 2 | none | no parent | LAND BGC |  | 1850 or 1700 | 2014 | 165 | no parent | Same as land-hist except with climate held constant
land-crop-grass | LUMIP | historical land-only with cropland as natural grassland | 2 | none | no parent | LAND BGC |  | 1850 or 1700 | 2014 | 165 | no parent | Same as land-hist but with all new crop and pastureland treated as unmanaged grassland
land-crop-noFert | LUMIP | historical land-only with no fertilizer | 2 | none | no parent | LAND BGC |  | 1850 or 1700 | 2014 | 165 | no parent | Same as land-hist but with fertilization rates and area held at 1850 levels/distribution
land-crop-noIrrig | LUMIP | historical land-only with no irrigation | 2 | none | no parent | LAND BGC |  | 1850 or 1700 | 2014 | 165 | no parent | Same as land-hist but with irrigated area held at 1850 levels
land-crop-noIrrigFert | LUMIP | historical land-only with managed crops but with irrigation and fertilization held constant | 2 | none | no parent | LAND BGC |  | 1850 or 1700 | 2014 | 165 | no parent | Same as land-hist except with plants in cropland area utilizing at least some form of crop management (e.g., planting and harvesting) rather than simulating cropland vegetation as a natural grassland. Irrigated area and fertilizer area/use should be held constant
land-hist | LS3MIP LUMIP | historical land-only | 1 | none | no parent | LAND | BGC | 1850 or 1700 | 2014 | 165 | no parent | Land only simulations
land-hist-altLu1 | LUMIP | historical land-only alternate land-use history | 2 | none | no parent | LAND BGC |  | 1850 or 1700 | 2014 | 165 | no parent | Land only simulations
land-hist-altLu2 | LUMIP | historical land-only alternate land use history | 2 | none | no parent | LAND BGC |  | 1850 or 1700 | 2014 | 165 | no parent | Land only simulations
land-hist-altStartYear | LUMIP | historical land-only alternate start year | 1 | none | no parent | LAND BGC |  | 1850 or 1700 | 2014 | 165 | no parent | Same as land-hist except starting from either 1700 (for models that typically start in 1850) or 1850 (for models that typically start in 1700)
land-hist-cruNcep | LS3MIP | as land-hist with CRU-NCEP forcings | 2 | none | no parent | LAND | BGC | 1850 | 2014 | 165 | no parent | Land only simulations
land-hist-princeton | LS3MIP | as land-hist with Princeton forcings | 2 | none | no parent | LAND | BGC | 1850 | 2014 | 165 | no parent | Land only simulations
land-hist-wfdei | LS3MIP | as land-hist with WFDEI forcings | 2 | none | no parent | LAND | BGC | 1850 | 2014 | 165 | no parent | Land only simulations
land-noFire | LUMIP | historical land-only with no human fire management | 2 | none | no parent | LAND BGC |  | 1850 or 1700 | 2014 | 165 | no parent | Same as land-hist but with anthropogenic ignition and suppression held to 1850 levels
land-noLu | LUMIP | historical land-only with no land-use change | 1 | none | no parent | LAND | BGC | 1850 or 1700 | 2014 | 165 | no parent | Same as land-hist except no land-use change
land-noPasture | LUMIP | historical land-only with constant pastureland | 2 | none | no parent | LAND BGC |  | 1850 or 1700 | 2014 | 165 | no parent | Same as land-hist but with grazing and other management on pastureland held at 1850 levels/distribution, i.e. all new pastureland is treated as unmanaged grassland (as in land-crop-grass)
land-noShiftCultivate | LUMIP | historical land-only with shifting cultivation turned off | 2 | none | no parent | LAND BGC |  | 1850 or 1700 | 2014 | 165 | no parent | Same as land-hist except shifting cultivation turned off. An additional LUC transitions dataset will be provided as a data layer within LUMIP LUH2 dataset with shifting cultivation deactivated
land-noWoodHarv | LUMIP | historical land-only with no wood harvest | 2 | none | no parent | LAND BGC |  | 1850 or 1700 | 2014 | 165 | no parent | Same as land-hist but with wood harvest maintained at 1850 amounts/areas
land-ssp126 | LS3MIP | future ssp1-2.6 land only | 1 | none | no parent | LAND | BGC | 2015 | 2100 | 86 | no parent | land only simulation for ssp1-2.6
land-ssp434 | LS3MIP | future ssp4-3.4 land only | 2 | none | no parent | LAND | BGC | 2015 | 2100 | 86 | no parent | land only simulation for ssp4-3.4
land-ssp585 | LS3MIP | future ssp5-8.5 land only | 1 | none | no parent | LAND | BGC | 2015 | 2100 | 86 | no parent | land only simulation for ssp5-8.5
lfmip-initLC | LS3MIP | initialized from "historical" run year 1980, but with land conditions initialized from pseudo-observations | 2 | none | historical | AOGCM | AER CHEM BGC | 1980 | 2014 | 35 | CMIP | Initialized pseudo-observations land
lfmip-pdLC | LS3MIP | prescribed land conditions (from current climate climatology) and initialized from "historical" run year 1980 | 1 | none | historical | AOGCM | AER CHEM BGC | 1980 | 2100 | 121 | CMIP | Prescribed land conditions 1980-2014 climate
lfmip-pdLC-cruNcep | LS3MIP | as LFMIP-pdLC with Land-Hist-cruNcep | 2 | none | historical | AOGCM | AER CHEM BGC | 1980 | 2100 | 121 | CMIP | Prescribed land conditions 1980-2014 climate with Land-Hist-cruNcep
lfmip-pdLC-princeton | LS3MIP | as LFMIP-pdLC with Land-Hist-princeton | 2 | none | historical | AOGCM | AER CHEM BGC | 1980 | 2100 | 121 | CMIP | Prescribed land conditions 1980-2014 climate with Land-Hist-princeton
lfmip-pdLC-wfdei | LS3MIP | as LFMIP-pdLC with Land-Hist-wfdei | 2 | none | historical | AOGCM | AER CHEM BGC | 1980 | 2100 | 121 | CMIP | Prescribed land conditions 1980-2014 climate with Land-Hist-wfdei
lfmip-rmLC | LS3MIP | prescribed land conditions (from running mean climatology) and initialized from "historical" run year 1980 | 2 | none | historical | AOGCM | AER CHEM BGC | 1980 | 2100 | 121 | CMIP | Prescribed land conditions 30yr running mean
lfmip-rmLC-cruNcep | LS3MIP | as LFMIP-rmLC with Land-Hist-cruNcep | 2 | none | historical | AOGCM | AER CHEM BGC | 1980 | 2100 | 121 | CMIP | Prescribed land conditions 30yr running mean with Land-Hist-cruNcep
lfmip-rmLC-princeton | LS3MIP | as LFMIP-rmLC with Land-Hist-princeton | 2 | none | historical | AOGCM | AER CHEM BGC | 1980 | 2100 | 121 | CMIP | Prescribed land conditions 30yr running mean with Land-Hist-princeton
lfmip-rmLC-wfdei | LS3MIP | as LFMIP-rmLC with Land-Hist-wfdei | 2 | none | historical | AOGCM | AER CHEM BGC | 1980 | 2100 | 121 | CMIP | Prescribed land conditions 30yr running mean with Land-Hist-wfdei
lgm | PMIP | last glacial maximum | 1 | none | no parent | AOGCM | AER CHEM BGC |  |  | 100 | no parent | main forcings: ice-sheet; trace gases, astronomical parameters, dust (forcing, or feedback if dust cycle represented in model)
lig127k | PMIP | last interglacial (127k) | 1 | none | no parent | AOGCM | AER CHEM BGC |  |  | 100 | no parent | main forcings: astronomical parameters, trace gases, dust (forcing, or feedback if dust cycle represented in model)
midHolocene | PMIP | mid-Holocene | 1 | none | no parent | AOGCM | AER CHEM BGC |  |  | 200 | no parent | main forcings: trace gases, orbital parameters, dust (forcing, or feedback if dust cycle represented in model)
midPliocene-eoi400 | PMIP | mid-Pliocene warm period | 1 | none | no parent | AOGCM | AER CHEM BGC |  |  | 100 | no parent | main forcings: trace gases, orography, ice-sheet
modelSST-futArcSIC | PAMIP | Atmosphere time slice with present day coupled model SST and future Arctic SIC | 3 | none | amip | AGCM | AER CHEM BGC | 2000 | 2001 | 1 | CMIP | PA4.2: investigate role of background state in response to Arctic sea ice
modelSST-pdSIC | PAMIP | Atmosphere time slice present day control with coupled model SST | 3 | none | amip | AGCM | AER CHEM BGC | 2000 | 2001 | 1 | CMIP | PA4.1: atmosphere only model present day control with coupled model SST
omip1 | OMIP | OMIP experiment forced by Large and Yeager (CORE-2, NCEP) atmospheric data set and initialized with observed physical and biogeochemical ocean data | 1 | none | no parent | OGCM | BGC |  |  | 310 | no parent | Global ocean - sea-ice coupled experiment forced with the Coordinated Ocean - ice Reference Experiments inter-annually varying atmospheric and river data sets for years 1948-2009. Initial ocean tracer fields are based on observations. Simulation length for at least 5 cycles of the 62-year forcing is required. The 5-cycle length is recommended to facilitate intercomparison within the experiment by using a common simulation length, but a longer simulation length is also accepted. For each simulation, set the beginning of the simulation (e.g., 1700 and 1638 for the 5-cycle and 6-cycle simulation, respectively) as the 'base time' of the time axis. Simulations with different simulation lengths by a single model are treated as members of an ensemble. Thus, different 'realization' indexes (e.g., r1, r2, r3, ...) should be used in a global attribute named 'variant_index' (e.g., r1i1p1f1). It is requested that information relevant to understanding the differences in members of an ensemble of simulations is reported in a global attribute named 'variant_info'. This information should also be recorded in the ES-DOC documentation of each experiment performed by a model and be made available via the 'further_info_url' attribute. All Priority=1 OMIP diagnostics (Omon, Oyr) are requested for all cycles of the 62-year forcing to quantify drift. All OMIP diagnostics (Priority=1,2,3) are requested for the last cycle
omip1-spunup | OMIP | OMIP experiment forced by Large and Yeager (CORE-2, NCEP) atmospheric data set and initialized from at least a 2000-year spin up of the coupled physical-biogeochemical model | 2 | none | no parent | OGCM BGC |  |  |  | 310 | no parent | Same as the omip1 experiment except that it is not initialized with observed climatologies; rather it is initialized with results from at least a 2000-year spin up of the coupled physical-biogeochemical models. The spin up simulations may be made with the classic online or offline approach, or with tracer-acceleration techniques or fast solvers. If an online approach is used, at the end of the 5th cycle of CORE-II forcing, the model's physical fields should be reinitialized to the values at the start of the 3rd cycle in order to avoid long-term drift in those fields and to assure that they will not diverge greatly from physical fields in the omip1 simulation. The spin up also includes radiocarbon to evaluate deep-ocean circulation
omip2 | OMIP | OMIP experiment forced by JRA55-do atmospheric data set and initialized with observed physical and biogeochemical ocean data | 3 | none | no parent | OGCM | BGC |  |  | 366 | no parent | Global ocean - sea-ice coupled experiment forced with the JRA55-do inter-annually varying atmospheric and river data sets for years 1958-2018. Initial ocean tracer fields are based on observations. Simulation length for at least 6 cycles of the 61-year forcing is required. The 6-cycle length is recommended to facilitate intercomparison within the experiment by using a common simulation length, but a longer simulation length is also accepted. In each simulation, set the beginning of the simulation (e.g., 1653 for the 6-cycle simulation) as the 'base time' of the time axis. Simulations with different simulation lengths by a single model are treated as members of an ensemble. Thus, different 'realization' indexes (e.g., r1, r2, r3, ...) should be used in a global attribute named 'variant_index' (e.g., r1i1p1f1). It is requested that information relevant to understanding the differences in members of an ensemble of simulations is reported in a global attribute named 'variant_info'. This information should also be recorded in the ES-DOC documentation of each experiment performed by a model and be made available via the 'further_info_url' attribute. All Priority=1 OMIP diagnostics (Omon, Oyr) are requested for all cycles of the 61-year forcing to quantify drift. All OMIP diagnostics (Priority=1,2,3) are requested for the last cycle
omip2-spunup | OMIP | OMIP experiment forced by JRA55-do atmospheric data set and initialized from at least a 2000-year spin up of the coupled physical-biogeochemical model | 3 | none | no parent | OGCM BGC |  |  |  | 366 | no parent | Same as the omip2 experiment except that it is not initialized with observed climatologies; rather it is initialized with results from at least a 2000-year spin up of the coupled physical-biogeochemical models. The spin up simulations may be made with the classic online or offline approach, or with tracer-acceleration techniques or fast solvers. If an online approach is used, at the end of the 6th cycle of the JRA55-do forcing, the model's physical fields should be reinitialized to the values at the start of the 4th cycle in order to avoid long-term drift in those fields and to assure that they will not diverge greatly from physical fields in the omip2 simulation. The spin up also includes radiocarbon to evaluate deep-ocean circulation
pa-futAntSIC | PAMIP | Partially-coupled time slice constrained by future Antarctic SIC | 2 | none | historical | AOGCM | AER CHEM BGC | 2000 | 2001 | 1 | CMIP | PA2.5: investigate response to Antarctic sea ice in coupled model
pa-futAntSIC-ext | PAMIP | Partially-coupled extended simulation with future Antarctic SIC | 3 | none | historical | AOGCM | AER CHEM BGC | 2000 | 2099 | 100 | CMIP | PA6.3: investigate decadal and longer timescale response to Antarctic sea ice
pa-futArcSIC | PAMIP | Partially-coupled time slice constrained by future Arctic SIC | 2 | none | historical | AOGCM | AER CHEM BGC | 2000 | 2001 | 1 | CMIP | PA2.3: investigate response to Arctic sea ice in coupled model
pa-futArcSIC-ext | PAMIP | Partially-coupled extended simulation with future Arctic SIC | 3 | none | historical | AOGCM | AER CHEM BGC | 2000 | 2099 | 100 | CMIP | PA6.2: investigate decadal and longer timescale response to Arctic sea ice
pa-pdSIC | PAMIP | Partially-coupled time slice contrained by present day SIC | 2 | none | historical | AOGCM | AER CHEM BGC | 2000 | 2001 | 1 | CMIP | PA2.1: coupled model present day control constrained by oberved sea ice
pa-pdSIC-ext | PAMIP | Partially-coupled extended simulation constrained by present day SIC | 3 | none | historical | AOGCM | AER CHEM BGC | 2000 | 2099 | 100 | CMIP | PA6.1: centennial coupled model present day control constrained by oberved sea ice
pa-piAntSIC | PAMIP | Partially-coupled time slice with pre-industrial Antarctic SIC | 2 | none | historical | AOGCM | AER CHEM BGC | 2000 | 2001 | 1 | CMIP | PA2.4: investigate response to Antarctic sea ice in coupled model
pa-piArcSIC | PAMIP | Partially-coupled time slice constrained by pre-industrial Arctic SIC | 2 | none | historical | AOGCM | AER CHEM BGC | 2000 | 2001 | 1 | CMIP | PA2.2: investigate response to Arctic sea ice in coupled model
past1000 | PMIP | last millennium | 1 | none | no parent | AOGCM | AER CHEM BGC | 850 | 1849 | 1000 | no parent | main forcings: trace gases, volcanoes, solar variability, land use
past1000-solaronly | PMIP | last millennium experiment using only solar forcing | 2 | none | no parent | AOGCM | AER CHEM BGC | 850 | 1849 | 1000 | no parent | Parallel experiment to past1000. Instead of the complete forcing set, only solar (TSI, SSI) forcing is considered
past1000-volconly | PMIP | last millennium experiment using only volcanic forcing | 2 | none | no parent | AOGCM | AER CHEM BGC | 850 | 1849 | 1000 | no parent | Parallel experiment to past1000. Instead of the complete forcing set, only volcanic forcing is considered
past2k | PMIP | last two millennia experiment | 3 | none | no parent | AOGCM | AER CHEM BGC | 1 | 1849 | 1849 | no parent | Experiment extending the past1000 simulation back in time to include the first millennium CE. Main forcings: trace gases, volcanoes, solar variability, land-use. past1000 forcings data sets include the first millennium, except for land-use. For the latter, a linear ramp-up to 850CE values is recommended
pdSST-futAntSIC | PAMIP | Atmosphere time slice with present day SST and future Antarctic SIC | 1 | none | amip | AGCM | AER CHEM BGC | 2000 | 2001 | 1 | CMIP | PA1.8: investigate response to Antarctic sea ice and its role in polar amplification
pdSST-futArcSIC | PAMIP | Atmosphere time slice with present day SST and future Arctic SIC | 1 | none | amip | AGCM | AER CHEM BGC | 2000 | 2001 | 1 | CMIP | PA1.6: investigate response to Arctic sea ice and its role in polar amplification
pdSST-futArcSICSIT | PAMIP | Atmosphere time slice with present day SST and future Arctic SIC and sea ice thickness | 3 | none | amip | AGCM | AER CHEM BGC | 2000 | 2001 | 1 | CMIP | PA1.10: investigate role of sea ice thickness in response to Arctic sea ice
pdSST-futBKSeasSIC | PAMIP | Atmosphere time slice with present day SST and future Barents and Kara Seas SIC | 3 | none | amip | AGCM | AER CHEM BGC | 2000 | 2001 | 1 | CMIP | PA3.2: investigate response to sea ice in Barents and Kara Seas
pdSST-futOkhotskSIC | PAMIP | Atmosphere time slice with present day SST and future Sea of Okhotsk SIC | 3 | none | amip | AGCM | AER CHEM BGC | 2000 | 2001 | 1 | CMIP | PA3.1: investigate response to sea ice in Sea of Okhotsk
pdSST-pdSIC | PAMIP | Atmosphere time slice with present day SST and SIC | 1 | none | amip | AGCM | AER CHEM BGC | 2000 | 2001 | 1 | CMIP | PA1.1: atmosphere only model present day control
pdSST-pdSICSIT | PAMIP | Atmosphere time slice constrained by present day conditions including sea ice thickness | 3 | none | amip | AGCM | AER CHEM BGC | 2000 | 2001 | 1 | CMIP | PA1.9: atmosphere only model present day control with sea ice thickness
pdSST-piAntSIC | PAMIP | Atmosphere time slice with present day SST and pre-industrial Antarctic SIC | 1 | none | amip | AGCM | AER CHEM BGC | 2000 | 2001 | 1 | CMIP | PA1.7: investigate response to Antarctic sea ice and its role in polar amplification
pdSST-piArcSIC | PAMIP | Atmosphere time slice with present day SST and pre-industrial Arctic SIC | 1 | none | amip | AGCM | AER CHEM BGC | 2000 | 2001 | 1 | CMIP | PA1.5: investigate response to Arctic sea ice and its role in polar amplification
piClim-2xDMS | AerChemMIP | pre-industrial climatological SSTs and forcing, but with doubled emissions of DMS | 3 | none | piControl | AGCM AER | CHEM BGC |  |  | 30 | CMIP | 1850 control with doubled emissions of DMS
piClim-2xNOx | AerChemMIP | pre-industrial climatological SSTs and forcing, but with doubled production of NOx due to lightning | 3 | none | piControl | AGCM AER CHEM | BGC |  |  | 30 | CMIP | 1850 control with doubled emissions of lightning NOx
piClim-2xVOC | AerChemMIP | pre-industrial climatological SSTs and forcing, but with doubled emissions of biogenic VOCs | 3 | none | piControl | AGCM AER CHEM | BGC |  |  | 30 | CMIP | 1850 control with doubled emissions of biogenic VOCs
piClim-2xdust | AerChemMIP | pre-industrial climatological SSTs and forcing, but with doubled emissions of dust | 2 | none | piControl | AGCM AER | CHEM BGC |  |  | 30 | CMIP | 1850 control with doubled dust emissions
piClim-2xfire | AerChemMIP | pre-industrial climatological SSTs and forcing, but with doubled emissions from fires | 3 | none | piControl | AGCM AER | CHEM BGC |  |  | 30 | CMIP | 1850 control with doubled emissions of fires
piClim-2xss | AerChemMIP | pre-industrial climatological SSTs and forcing, but with doubled emissions of sea salt | 2 | none | piControl | AGCM AER | CHEM BGC |  |  | 30 | CMIP | 1850 control with doubled sea salt emissions
piClim-4xCO2 | RFMIP | effective radiative forcing by 4xCO2 | 1 | none | piControl | AGCM | AER CHEM |  |  | 30 | CMIP | As in piClim-control but with 4xCO2
piClim-BC | AerChemMIP | pre-industrial climatological SSTs and forcing, but with 2014 black carbon emissions | 2 | none | piControl | AGCM AER | CHEM BGC |  |  | 30 | CMIP | Perturbation from 1850 control using 2014 BC emissions
piClim-CH4 | AerChemMIP | pre-industrial climatological SSTs and forcing, but with 2014 methane concentrations (including chemistry) | 1 | none | piControl | AGCM AER CHEM | BGC |  |  | 30 | CMIP | Perturbation from 1850 control using 2014 CH4 concentrations
piClim-HC | AerChemMIP | pre-industrial climatological SSTs and forcing, but with 2014 halocarbon concentrations (including chemistry) | 1 | none | piControl | AGCM AER CHEM | BGC |  |  | 30 | CMIP | Perturbation from 1850 control using 2014 halocarbon concentrations
piClim-N2O | AerChemMIP | pre-industrial climatological SSTs and forcing, but with 2014 N2O concentrations (including chemistry) | 2 | none | piControl | AGCM AER CHEM | BGC |  |  | 30 | CMIP | Perturbation from 1850 control using 2014 N2O concentrations
piClim-NH3 | AerChemMIP | pre-industrial climatological SSTs and forcing, but with 2014 ammonia emissions | 3 | none | piControl | AGCM AER | CHEM BGC |  |  | 30 | CMIP | Perturbation from 1850 control using 2014 NH3 emissions
piClim-NOx | AerChemMIP | pre-industrial climatological SSTs and forcing, but with 2014 NOx emissions | 3 | none | piControl | AGCM AER CHEM | BGC |  |  | 30 | CMIP | Perturbation from 1850 control using 2014 NOx emissions
piClim-NTCF | AerChemMIP | pre-industrial climatological SSTs and forcing, but with 2014 NTCF emissions | 1 | none | piControl | AGCM AER | CHEM BGC |  |  | 30 | CMIP | Perturbation from 1850 control using 2014 aerosol and ozone precursor emissions
piClim-O3 | AerChemMIP | pre-industrial climatological SSTs and forcing, but with 2014 ozone precursor emissions | 2 | none | piControl | AGCM AER CHEM | BGC |  |  | 30 | CMIP | Perturbation from 1850 control using 2014 ozone precursor emissions
piClim-OC | AerChemMIP | pre-industrial climatological SSTs and forcing, but with 2014 organic carbon emissions | 3 | none | piControl | AGCM AER | CHEM BGC |  |  | 30 | CMIP | Perturbation from 1850 control using 2014 OC emissions
piClim-SO2 | AerChemMIP | pre-industrial climatological SSTs and forcing, but with 2014 SO2 emissions | 3 | none | piControl | AGCM AER | CHEM BGC |  |  | 30 | CMIP | Perturbation from 1850 control using 2014 SO2 emissions
piClim-VOC | AerChemMIP | pre-industrial climatological SSTs and forcing, but with 2014 VOC emissions | 3 | none | piControl | AGCM AER CHEM | BGC |  |  | 30 | CMIP | Perturbation from 1850 control using 2014 CO/VOC emissions
piClim-aer | RFMIP AerChemMIP | effective radiative forcing by present-day aerosols | 1 | none | piControl | AGCM | AER CHEM BGC |  |  | 30 | CMIP | As in piClim-control but with with present-day aerosols. Note that this experiment is considered to be tier 1 by RFMIP but tier 2 by AerChemMIP
piClim-anthro | RFMIP | effective radiative forcing by present day anthropogenic agents | 1 | none | piControl | AGCM | AER CHEM |  |  | 30 | CMIP | As in piClim-control but with present-day anthropogenic forcing (greenhouse gases, ozone, aerosols and land-use)
piClim-control | RFMIP AerChemMIP | Control simulation providing baseline for evaluating effective radiative forcing (ERF) | 1 | none | piControl | AGCM | AER CHEM BGC |  |  | 30 | CMIP | 30-year atmosphere only integration using preindustrial sea-surface temperature and sea-ice climatology. Interactive vegetation
piClim-ghg | RFMIP | effective radiative forcing by present-day greenhouse gases | 1 | none | piControl | AGCM | AER CHEM BGC |  |  | 30 | CMIP | As in piClim-control but with present-day non-ozone greenhouse gases
piClim-histaer | RFMIP | transient effective radiative forcing by aerosols | 2 | none | piControl | AGCM | AER CHEM BGC | 1850 | 2100 | 251 | CMIP | Time-varying forcing by aerosols. SST and sea ice fixed at preindustrial control. Interactive vegetation
piClim-histall | RFMIP | transient effective radiative forcing | 2 | none | piControl | AGCM | AER CHEM BGC | 1850 | 2100 | 251 | CMIP | Time-varying forcing. SST and sea ice fixed at preindustrial control. Interactive vegetation
piClim-histghg | RFMIP | transient effective radiative forcing by greenhouse gases | 2 | none | piControl | AGCM | AER CHEM BGC | 1850 | 2100 | 251 | CMIP | Time-varying forcing by non-ozone GHGs. SST and sea ice fixed at preindustrial control. Interactive vegetation
piClim-histnat | RFMIP | transient effective radiative forcing by natural perturbations | 2 | none | piControl | AGCM | AER CHEM BGC | 1850 | 2100 | 251 | CMIP | Time-varying forcing from volcanos, solar variability, etc. SST and sea ice fixed at preindustrial control. Interactive vegetation
piClim-lu | RFMIP | effective radiative forcing by present-day land use | 1 | none | piControl | AGCM | AER CHEM BGC |  |  | 30 | CMIP | As in piClim-control but with present-day land use
piClim-spAer-aer | RFMIP | effective radiative forcing at present day with specified anthropogenic aerosol optical properties, all forcings | 2 | none | piControl | AGCM |  |  |  |  | CMIP | Prescribed anthropogenic aerosol optical properties. Aerosol forcings
piClim-spAer-anthro | RFMIP | effective radiative forcing at present day with specified anthropogenic aerosol optical properties, anthropogenic forcings | 2 | none | piControl | AGCM |  |  |  |  | CMIP | Prescribed anthropogenic aerosol optical properties. Anthropogenic forcings
piClim-spAer-histaer | RFMIP | transient effective radiative forcing with specified anthropogenic aerosol optical properties, aerosol forcing | 2 | none | piControl | AGCM |  | 1850 | 2014 | 165 | CMIP | Prescribed anthropogenic aerosol optical properties. Aerosol forcings
piClim-spAer-histall | RFMIP | transient effective radiative forcing with specified anthropogenic aerosol optical properties, all forcings | 2 | none | piControl | AGCM |  | 1850 | 2014 | 165 | CMIP | Prescribed anthropogenic aerosol optical properties. All anthropogenic and natural forcings
piControl | CMIP | pre-industrial control | 1 | none | piControl-spinup | AOGCM | AER CHEM BGC |  |  | 500 | CMIP | DECK: control
piControl-cmip5 | CMIP | pre-industrial control (CMIP5-era [1850-2005] forcing) | 2 | none | piControl-spinup-cmip5 | AOGCM | AER CHEM BGC |  |  | 500 | CMIP | DECK: control (CMIP5-era pre-industrial forcing)
piControl-spinup | CMIP | pre-industrial control (spin-up) | 2 | none | no parent | AOGCM | AER CHEM BGC |  |  | 100 | no parent | DECK: spin-up portion of the control
piControl-spinup-cmip5 | CMIP | pre-industrial control (spin-up; CMIP5-era [1850-2005] forcing) | 2 | none | no parent | AOGCM | AER CHEM BGC |  |  | 100 | CMIP | DECK: spin-up portion of the control (CMIP5-era pre-industrial forcing)
piControl-withism | ISMIP6 | preindustrial control with interactive ice sheet | 1 | none | no parent | AOGCM ISM | AER CHEM BGC |  |  | 500 | no parent | Pre-industrial control simulation that includes interactive ice sheets
piSST | CFMIP | experiment forced with pre-industrial SSTs, sea ice and atmospheric constituents | 2 | none | no parent | AGCM | AER CHEM |  |  | 30 | no parent | An AGCM experiment with monthly-varying SSTs, sea-ice, atmospheric constituents and any other necessary boundary conditions (e.g. vegetation if required) taken from each model's own piControl run (using the 30 years of piControl that are parallel to years 111-140 of its abrupt-4xCO2 run). Dynamic vegetation should be turned off in all the piSST set of experiments
piSST-4xCO2 | CFMIP | as piSST with radiation and vegetation seeing 4xCO2 | 2 | none | no parent | AGCM | AER CHEM |  |  | 30 | no parent | Same as piSST but CO2 is quadrupled. The increase in CO2 is seen by both the radiation scheme and vegetation
piSST-4xCO2-rad | CFMIP | as piSST with radiation-only seeing 4xCO2 | 2 | none | no parent | AGCM | AER CHEM |  |  | 30 | no parent | Same as piSST but CO2 as seen by the radiation scheme is quadrupled
piSST-4xCO2-solar | GeoMIP | preindustrial control SSTs with quadrupled CO2 and solar reduction | 2 | none | piControl | AGCM | AER CHEM |  |  | 10 | CMIP | Time slice at 1850 (picontrol) for G1ext to examine radiative forcing of abrupt-4xCO2
piSST-pdSIC | PAMIP | Atmosphere time slice with pre-industrial SST and present day SIC | 1 | none | amip | AGCM | AER CHEM BGC | 2000 | 2001 | 1 | CMIP | PA1.3: investigate role of SST in polar amplification
piSST-piSIC | PAMIP | Atmosphere time slice with pre-industrial SST and SIC | 2 | none | amip | AGCM | AER CHEM BGC | 2000 | 2001 | 1 | CMIP | PA1.2: atmosphere only model pre-industrial control
piSST-pxK | CFMIP | as piSST with uniform SST increase with magnitude based on abrupt-4xCO2 response | 2 | none | no parent | AGCM | AER CHEM |  |  | 20 | no parent | Same as piSST, but with a spatially and temporally uniform SST anomaly applied on top of the monthly-varying piSST SSTs. The magnitude of the uniform increase is taken from each model's global, climatological annual mean SST change between abrupt-4xCO2 minus piControl (using the mean of years 111-140 of abrupt-4xCO2, and the parallel 30-year section of piControl)
rad-irf | RFMIP | offline assessment of radiative transfer parmeterizations in clear skies | 1 | none | no parent | RAD |  |  |  |  | no parent | Offline radiation calculations
rcp26-cmip5 | ScenarioMIP | future projection based on CMIP5-era RCP2.6 scenario (CMIP5-era [2006-2100] forcing) | 3 | none | historical-cmip5 | AOGCM | AER CHEM BGC | 2006 | 2100 or 2300 | 95 | CMIP | future scenario with low radiative forcing by the end of century. Following RCP2.6 global forcing pathway. Concentration-driven (CMIP5-era [2006-2100] forcing)
rcp45-cmip5 | ScenarioMIP | future projection based on CMIP5-era RCP4.5 scenario (CMIP5-era [2006-2100] forcing) | 3 | none | historical-cmip5 | AOGCM | AER CHEM BGC | 2006 | 2100 or 2300 | 95 | CMIP | future scenario with low-medium radiative forcing by the end of century. Following RCP4.5 global forcing pathway. Concentration-driven (CMIP5-era [2006-2100] forcing)
rcp60-cmip5 | ScenarioMIP | future projection based on CMIP5-era RCP6.0 scenario (CMIP5-era [2006-2100] forcing) | 3 | none | historical-cmip5 | AOGCM | AER CHEM BGC | 2006 | 2100 or 2300 | 95 | CMIP | future scenario with medium radiative forcing by the end of century. Following RCP6.0 global forcing pathway. Concentration-driven (CMIP5-era [2006-2100] forcing)
rcp85-cmip5 | ScenarioMIP | future projection based on CMIP5-era RCP8.5 scenario (CMIP5-era [2006-2100] forcing) | 3 | none | historical-cmip5 | AOGCM | AER CHEM BGC | 2006 | 2100 or 2300 | 95 | CMIP | future scenario with high radiative forcing by the end of century. Following RCP8.5 global forcing pathway. Concentration-driven (CMIP5-era [2006-2100] forcing)
spinup-1950 | HighResMIP | coupled spinup with fixed 1950s forcings from 1950 initial conditions (with ocean at rest) to provide initial condition for control-1950 and hist-1950 | 2 | none | no parent | AOGCM | AER |  |  | 30 | no parent | Coupled integration from ocean rest state using recommended HighResMIP protocol spinup, starting from 1950 ocean temperature and salinity analysis EN4, using constant 1950s forcing. At least 30 years to satisfy near surface quasi-equilibrium
ssp119 | ScenarioMIP | low-end scenario reaching 1.9 W m-2, based on SSP1 | 2 | none | historical | AOGCM | AER CHEM BGC | 2015 | 2100 | 86 | CMIP | Future scenario with low radiative forcing throughout reaching about 1.9 W/m2 in 2100 based on SSP1. Concentration-driven
ssp126 | ScenarioMIP | update of RCP2.6 based on SSP1 | 1 | none | historical | AOGCM | AER CHEM BGC | 2015 | 2100 or 2300 | 86 | CMIP | Future scenario with low radiative forcing by the end of century. Following approximately RCP2.6 global forcing pathway but with new forcing based on SSP1. Concentration-driven. As a tier 2 option, this simulation should be extended to year 2300
ssp126-ssp370Lu | LUMIP | SSP1-2.6 with SSP3-7.0 land use | 1 | none | historical | AOGCM | AER CHEM BGC | 2015 | 2100 | 86 | CMIP | Additional land use policy sensitivity simulation for low radiative forcing scenario, keep all forcings the same as ScenarioMIP SSP1-2.6 (afforestation scenario), but replace land use from SSP3-7 (afforestation) scenario; concentration-driven
ssp245 | ScenarioMIP | update of RCP4.5 based on SSP2 | 1 | none | historical | AOGCM | AER CHEM BGC | 2015 | 2100 | 86 | CMIP | Future scenario with medium radiative forcing by the end of century. Following approximately RCP4.5 global forcing pathway but with new forcing based on SSP2. Concentration-driven
ssp245-GHG | DAMIP | well-mixed GHG-only SSP2-4.5 run | 2 | none | hist-GHG | AOGCM | AER CHEM BGC | 2021 | 2100 | 80 | DAMIP | Extension of well-mixed GHG-only run under SSP2-4.5. Models with interactive chemistry schemes should either turn off the chemistry or use a preindustrial climatology of stratospheric and tropospheric ozone in their radiation schemes
ssp245-aer | DAMIP | aerosol-only SSP2-4.5 run | 3 | none | hist-aer | AOGCM | AER CHEM BGC | 2021 | 2100 | 80 | DAMIP | Extension of aerosol-only run under SSP2-4.5
ssp245-cov-GHG | DAMIP | 2-year Covid-19 emissions blip including well mixed GHG only, based upon ssp245 | 3 | none | ssp245 | AOGCM | AER CHEM BGC | 2020 | 2024 or 2050 | 5 | ScenarioMIP | Detection and attribution experiment: well-mixed GHG-only run based on ssp245-covid, with 2-year perturbation to emissions for 2020 and 2021 due to Covid-19 pandemic restrictions. Concentration-driven
ssp245-cov-aer | DAMIP | 2-year Covid-19 emissions blip including anthropogenic aerosols only, based upon ssp245 | 3 | none | ssp245 | AOGCM | AER CHEM BGC | 2020 | 2024 or 2050 | 5 | ScenarioMIP | Detection and attribution experiment: aerosol-only run based on ssp245-covid, with 2-year perturbation to emissions for 2020 and 2021 due to Covid-19 pandemic restrictions. Concentration-driven
ssp245-cov-fossil | DAMIP | 2-year Covid-19 emissions blip followed by increased emissions due to a fossil-fuel based recovery, based upon ssp245 | 3 | none | ssp245 | AOGCM | AER CHEM BGC | 2020 | 2050 | 31 | ScenarioMIP | Future scenario based on ssp245, but following a path of increased emissions due to a fossil-fuel rebound economic recovery from the Covid-19 pandemic restrictions. Concentration-driven
ssp245-cov-modgreen | DAMIP | 2-year Covid-19 emissions blip followed by moderate-green stimulus recovery, based upon ssp245 | 3 | none | ssp245 | AOGCM | AER CHEM BGC | 2020 | 2050 | 31 | ScenarioMIP | Future scenario based on ssp245, but following a path of reduced emissions due to a moderate-green stimulus economic recovery from the Covid-19 pandemic restrictions. Concentration-driven
ssp245-cov-strgreen | DAMIP | 2-year Covid-19 emissions blip followed by strong-green stimulus recovery, based upon ssp245 | 2 | none | ssp245 | AOGCM | AER CHEM BGC | 2020 | 2050 | 31 | ScenarioMIP | Future scenario based on ssp245, but following a path of reduced emissions due to a strong-green stimulus economic recovery from the Covid-19 pandemic restrictions. Concentration-driven
ssp245-covid | DAMIP | 2-year Covid-19 emissions blip based upon ssp245 | 2 | none | ssp245 | AOGCM | AER CHEM BGC | 2020 | 2024 or 2050 | 5 | ScenarioMIP | Future scenario based on ssp245, but with 2-year perturbation to emissions for 2020 and 2021 due to Covid-19 pandemic restrictions. Emissions revert to ssp245 after this. Concentration-driven
ssp245-nat | DAMIP | natural-only SSP2-4.5 run | 3 | none | hist-nat | AOGCM | AER CHEM BGC | 2021 | 2100 | 80 | DAMIP | Extension of natural-only run under SSP2-4.5
ssp245-stratO3 | DAMIP | stratospheric ozone-only SSP2-4.5 (ssp245) run | 2 | none | hist-stratO3 | AOGCM | AER BGC | 2021 | 2100 | 80 | DAMIP | Extension of stratospheric ozone-only run under SSP2-4.5 (ssp245). In models with coupled chemistry, the chemistry scheme should be turned off, and the simulated ensemble mean monthly mean 3D stratospheric ozone concentrations from the SSP2-4.5 simulations should be prescribed. Tropospheric ozone should be fixed at 3D long-term monthly mean piControl values, with a value of 100 ppbv ozone concentration in this piControl climatology used to separate the troposphere from the stratosphere. In models without coupled chemistry the same stratospheric ozone prescribed in SSP2-4.5 should be prescribed. Stratospheric ozone concentrations will be provided by CCMI
ssp370 | ScenarioMIP AerChemMIP | gap-filling scenario reaching 7.0 based on SSP3 | 1 | none | historical | AOGCM | AER CHEM BGC | 2015 | 2100 | 86 | CMIP | Future scenario with high radiative forcing by the end of century. Reaches about 7.0 W/m2 by 2100; fills gap in RCP forcing pathways between 6.0 and 8.5 W/m2. Concentration-driven
ssp370-lowNTCF | AerChemMIP | SSP3-7.0, with low NTCF emissions | 1 | none | historical | AOGCM AER | CHEM BGC | 2015 | 2100 | 86 | CMIP | Future SSP3-7.0 with reduced NTCF emissions
ssp370-lowNTCFCH4 | AerChemMIP | SSP3-7.0, with low NTCF emissions and methane concentrations | 3 | none | historical | AOGCM AER | CHEM BGC | 2015 | 2100 | 86 | CMIP | This experiment is identical to ssp370-lowNTCF except that the methane concentrations also follow the "low" scenario from SSP3-7.0_lowNTCF
ssp370-ssp126Lu | LUMIP | SSP3-7.0 with SSP1-2.6 land use | 1 | none | historical | AOGCM | AER CHEM BGC | 2015 | 2100 | 86 | CMIP | Additional land use policy sensitivity simulation for high radiative forcing scenario, keep all forcings the same as ScenarioMIP SSP3-7 (deforestation scenario), but replace land use from SSP1-2.6 (afforestation) scenario; concentration-driven
ssp370SST | AerChemMIP | SSP3-7.0, with SSTs prescribed from ssp370 | 1 | none | historical | AGCM AER | CHEM BGC | 2015 | 2100 | 86 | CMIP | Future SSP3-7.0, with SSTs prescribed from ssp370
ssp370SST-lowAer | AerChemMIP | SSP3-7.0, prescribed SSTs, with low aerosol emissions | 2 | none | historical | AGCM AER | CHEM BGC | 2015 | 2100 | 86 | CMIP | Future SSP3-7.0 with reduced aerosol emissions (from ssp370-lowNTCF), prescribed SSTs
ssp370SST-lowBC | AerChemMIP | SSP3-7.0, prescribed SSTs, with low black carbon emissions | 2 | none | historical | AGCM AER | CHEM BGC | 2015 | 2100 | 86 | CMIP | Future SSP3-7.0 with reduced black carbon emissions, prescribed SSTs
ssp370SST-lowCH4 | AerChemMIP | SSP3-7.0, prescribed SSTs, with low methane concentrations | 1 | none | historical | AGCM AER CHEM | BGC | 2015 | 2100 | 86 | CMIP | Future SSP3-7.0 with reduced CH4 concentrations, prescribed SSTs
ssp370SST-lowNTCF | AerChemMIP | SSP3-7.0, prescribed SSTs, with low NTCF emissions | 1 | none | historical | AGCM AER | CHEM BGC | 2015 | 2100 | 86 | CMIP | Future SSP3-7.0 with reduced NTCF emissions, prescribed SSTs
ssp370SST-lowNTCFCH4 | AerChemMIP | SSP3-7.0, prescribed SSTs, with low NTCF emissions and methane concentrations | 3 | none | historical | AGCM AER | CHEM BGC | 2015 | 2100 | 86 | CMIP | This experiment is identical to ssp370SST-lowNTCF except that the methane concentrations also follow the "low" scenario from SSP3-7.0_lowNTCF
ssp370SST-lowO3 | AerChemMIP | SSP3-7.0, prescribed SSTs, with low ozone precursor emissions | 2 | none | historical | AGCM AER CHEM | BGC | 2015 | 2100 | 86 | CMIP | Future SSP3-7.0 with reduced ozone precursor emissions (from ssp370-lowNTCF), prescribed SSTs
ssp370SST-ssp126Lu | AerChemMIP | SSP3-7.0, prescribed SSTs, with SSP1-2.6 land use | 1 | none | historical | AGCM AER | CHEM BGC | 2015 | 2100 | 86 | CMIP | Future SSP3-7.0 with low land use change (from ssp126), prescribed SSTs
ssp370pdSST | AerChemMIP | SSP3-7.0, with SSTs prescribed as present day | 2 | none | historical | AGCM AER | CHEM BGC | 2015 | 2100 | 86 | CMIP | Experimental set up as ssp370SST except sea surface temperatures (SST) and sea ice concentrations (SICONC) are from a 2005-2014 climatology. Diagnostics are as ssp370SST
ssp434 | ScenarioMIP | gap-filling scenario reaching 3.4 based on SSP4 | 2 | none | historical | AOGCM | AER CHEM BGC | 2015 | 2100 | 86 | CMIP | Future scenario with low radiative forcing by the end of century. Reaches about 3.4 W/m2 by 2100; fills gap in RCP forcing pathways between 4.5 and 2.6 W/m2. Concentration-driven
ssp460 | ScenarioMIP | update of RCP6.0 based on SSP4 | 2 | none | historical | AOGCM | AER CHEM BGC | 2015 | 2100 | 86 | CMIP | Future scenario with medium radiative forcing by the end of century. Following approximately RCP6.0 global forcing pathway but with new forcing based on SSP4. Concentration-driven
ssp534-over | ScenarioMIP | overshoot of 3.4 W/m**2 branching from ssp585 in 2040 | 2 | none | ssp585 | AOGCM | AER CHEM BGC | 2040 | 2100 or 2300 | 61 | ScenarioMIP | 21st century overshoot scenario relative to SSP5_34. Branches from SSP5_85 at 2040 with emissions reduced to zero by 2070 and negative thereafter. This simulation should optionally be extended to year 2300
ssp534-over-bgc | C4MIP | biogeochemically-coupled version of the RCP3.4-overshoot based on SSP5 | 2 | none | ssp585-bgc | AOGCM BGC | AER CHEM | 2040 | 2100 or 2300 | 61 | C4MIP | This simulation should optionally be extended to year 2300
ssp585 | ScenarioMIP | update of RCP8.5 based on SSP5 | 1 | none | historical | AOGCM | AER CHEM BGC | 2015 | 2100 or 2300 | 86 | CMIP | Future scenario with high radiative forcing by the end of century. Following approximately RCP8.5 global forcing pathway but with new forcing based on SSP5. Concentration-driven. As a tier 2 option, this simulation should be extended to year 2300
ssp585-bgc | C4MIP | biogeochemically-coupled version of the RCP8.5 based on SSP5 | 2 | none | hist-bgc | AOGCM BGC | AER CHEM | 2015 | 2100 or 2300 | 86 | C4MIP | Concentration-driven future scenario simulation, biogeochemically-coupled. This simulation should optionally be extended to year 2300
ssp585-withism | ISMIP6 | ssp585 with interactive ice sheet | 2 | none | historical-withism | AOGCM ISM | AER CHEM BGC | 2015 | 2100 or 2300 | 86 | ISMIP6 | Future climate from ScenarioMIP SSP5-8.5 simulation that includes interactive ice sheets. Set up follows the standard SSP5-8.5 experiment
volc-cluster-21C | VolMIP | volcanic cluster experiment under 21st century SSP2-4.5 scenario | 3 | none | historical | AOGCM | AER CHEM BGC | 2015 | 2100 | 86 | CMIP | Parallel experiment to volc-cluster-ctrl, using restart files from the end of the historical simulation instead of from piControl, and boundary conditions from the 21st century SSP2-4.5 scenario experiment of ScenarioMIP
volc-cluster-ctrl | VolMIP | 19th century volcanic cluster initialized from PiControl | 2 | none | piControl | AOGCM | AER CHEM BGC |  |  | 50 | CMIP | Early 19th century cluster of strong tropical volcanic eruptions, including the 1809 event of unknown location, the 1815 Tambora and 1835 Cosigueina eruptions. Experiment initialized from PiControl
volc-cluster-mill | VolMIP | 19th century volcanic cluster initialized from past1000 | 3 | none | past1000 | AOGCM | AER CHEM BGC | 1790 | 1858 | 69 | PMIP | Parallel experiment to volc-cluster-ctrl but with initial conditions taken from last millennium simulation to account for the effects of a more realistic history of past natural forcing. All forcings except volcanic kept constant from year AD 1790 on
volc-long-eq | VolMIP | idealized equatorial volcanic eruption emitting 56.2 Tg SO2 | 1 | none | piControl | AOGCM | AER CHEM BGC |  |  | 20 | CMIP | Idealized equatorial eruption corresponding to an initial emission of 56.2 Tg of SO2. The eruption magnitude corresponds to recent estimates for the 1815 Tambora eruption (Sigl et al., 2015), the largest historical tropical eruption, which was linked to the so-called "year without a summer" in 1816. Experiment initialized from PiControl
volc-long-hlN | VolMIP | idealized Northern Hemisphere high-latitude eruption emitting 28.1 Tg of SO2 | 2 | none | piControl | AOGCM | AER CHEM BGC |  |  | 20 | CMIP | Idealized Northern Hemisphere high-latitude eruption emitting 28.1 Tg of SO2. Experiment initialized from PiControl
volc-long-hlS | VolMIP | Idealized Southern Hemisphere high-latitude eruption emitting 28.1 Tg of SO2 | 3 | none | piControl | AOGCM | AER CHEM BGC |  |  | 20 | CMIP | Idealized Southern Hemisphere high-latitude eruption emitting 28.1 Tg of SO2. Experiment initialized from PiControl
volc-pinatubo-full | VolMIP | Pinatubo experiment | 1 | none | piControl | AOGCM | AER CHEM BGC |  |  | 3 | CMIP | 1991 Pinatubo forcing as used in the CMIP6 historical simulations. Requires special diagnostics of radiative and latent heating rates. A large number of ensemble members is required to address internal atmospheric variability
volc-pinatubo-slab | VolMIP | Pinatubo experiment with slab ocean | 3 | none | control-slab | AGCM SLAB | AER CHEM BGC |  |  | 3 | VolMIP | As volc-pinatubo-full, but with a slab ocean
volc-pinatubo-strat | VolMIP | Pinatubo experiment with partial radiative forcing, includes only stratospheric warming | 1 | none | piControl | AOGCM | AER CHEM BGC |  |  | 3 | CMIP | As volc-pinatubo-full, but with prescribed perturbation to the total (LW+SW) radiative heating rates
volc-pinatubo-surf | VolMIP | Pinatubo experiment with partial radiative forcing, solar radiation scattering only | 1 | none | piControl | AOGCM | AER CHEM BGC |  |  | 3 | CMIP | As volc-pinatubo-full, but with prescribed perturbation to the shortwave flux to mimic the attenuation of solar radiation by volcanic aerosols
yr2010CO2 | CDRMIP | concentration-driven fixed 2010 forcing | 3 | none | historical | AOGCM BGC | AER CHEM | 2010 | 2115 | 106 | CMIP | Branch from beginning of year 2010 of the historical simulation with CO2 concentration and all other forcing held fixed at 2010 level (part of the CDR-yr2010-pulse experiment to diagnose CO2 emissions)